@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,17 +17,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_ASSETS_EXTERNAL_H
-#define INCLUDED_ASSETS_EXTERNAL_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string assets_external_url ();
-string assets_external (void * webserver_request);
+std::string assets_external_url ();
+std::string assets_external (Webserver_Request& webserver_request);
 
-string assets_external_logic_link_addon ();
-
-
-#endif
+std::string assets_external_logic_link_addon ();
