@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <config/globals.h>
 #include <database/logs.h>
 #include <flate/flate.h>
-using namespace std;
 
 
 Assets_View::Assets_View ()
@@ -38,26 +37,26 @@ Assets_View::Assets_View ()
 
 
 // Sets a variable (key and value) for the html template.
-void Assets_View::set_variable (string key, string value)
+void Assets_View::set_variable (const std::string& key, const std::string& value)
 {
   m_variables[key] = value;
 }
 
 
 // Enable displaying a zone in the html template.
-void Assets_View::enable_zone (string zone)
+void Assets_View::enable_zone (const std::string& zone)
 {
   m_zones [zone] = true;
 }
 
 
-void Assets_View::disable_zone (string zone)
+void Assets_View::disable_zone (const std::string& zone)
 {
   m_zones.erase (zone);
 }
 
 
-void Assets_View::add_iteration (string key, map <string, string> value)
+void Assets_View::add_iteration (const std::string& key, const std::map <std::string, std::string>& value)
 {
   m_iterations[key].push_back (value);
 }
@@ -69,32 +68,31 @@ void Assets_View::add_iteration (string key, map <string, string> value)
 // 2: Basename of the html template without the .html extension.
 // Setting the session variables in the template is postponed to the very last moment,
 // since these could change during the course of the calling page.
-string Assets_View::render (string tpl1, string tpl2)
+std::string Assets_View::render (const std::string& tpl1, const std::string& tpl2)
 {
   // Variable tpl is a relative path. Make it a full one.
-  string tpl = filter_url_create_root_path ({tpl1, tpl2 + ".html"});
+  const std::string tpl = filter_url_create_root_path ({tpl1, tpl2 + ".html"});
 
   // The flate engine crashes if the template does not exist, so be sure it exists.  
   if (!file_or_dir_exists (tpl)) {
     Database_Logs::log ("Cannot find template file " + tpl);
-    return string();
+    return std::string();
   }
 
   // Instantiate and fill the template engine. 
   Flate flate;
 
   // Copy the variables and zones and iterations to the engine.
-  map <string, string>::iterator iter1;
+  std::map <std::string, std::string>::iterator iter1 {};
   for (iter1 = m_variables.begin (); iter1 != m_variables.end(); ++iter1) {
     flate.set_variable (iter1->first, iter1->second);
   }
-  map <string, bool>::iterator iter2;
+  std::map <std::string, bool>::iterator iter2{};
   for (iter2 = m_zones.begin (); iter2 != m_zones.end(); ++iter2) {
     flate.enable_zone (iter2->first);
   }
   flate.iterations = m_iterations;
 
   // Get and return the page contents.
-  string page = flate.render (tpl);
-  return page;
+  return flate.render (tpl);
 }
