@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -41,81 +41,79 @@
 #include <bb/manage.h>
 
 
-string bible_book_url ()
+std::string bible_book_url ()
 {
   return "bible/book";
 }
 
 
-bool bible_book_acl (void * webserver_request)
+bool bible_book_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
 }
 
 
-string bible_book (void * webserver_request)
+std::string bible_book (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  string page;
+  std::string page {};
   
   Assets_Header header = Assets_Header (translate("Book"), webserver_request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
-  header.addBreadCrumb (bible_manage_url (), menu_logic_bible_manage_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (bible_manage_url (), menu_logic_bible_manage_text ());
   page = header.run ();
   
-  Assets_View view;
+  Assets_View view {};
   
-  string success_message;
-  string error_message;
+  std::string success_message {};
+  std::string error_message {};
   
   // The name of the Bible.
-  string bible = AccessBible::Clamp (request, request->query["bible"]);
-  view.set_variable ("bible", escape_special_xml_characters (bible));
+  const std::string bible = access_bible::clamp (webserver_request, webserver_request.query["bible"]);
+  view.set_variable ("bible", filter::strings::escape_special_xml_characters (bible));
   
   // The book.
-  int book = convert_to_int (request->query ["book"]);
-  view.set_variable ("book", convert_to_string (book));
-  string book_name = Database_Books::getEnglishFromId (book);
-  view.set_variable ("book_name", escape_special_xml_characters (book_name));
+  const int book = filter::strings::convert_to_int (webserver_request.query ["book"]);
+  view.set_variable ("book", std::to_string (book));
+  const std::string book_name = database::books::get_english_from_id (static_cast<book_id>(book));
+  view.set_variable ("book_name", filter::strings::escape_special_xml_characters (book_name));
   
   // Whether the user has write access to this Bible book.
-  bool write_access = AccessBible::BookWrite (request, string(), bible, book);
+  const bool write_access = access_bible::book_write (webserver_request, std::string(), bible, book);
   if (write_access) view.enable_zone ("write_access");
   
   // Delete chapter.
-  string deletechapter = request->query ["deletechapter"];
+  const std::string deletechapter = webserver_request.query ["deletechapter"];
   if (!deletechapter.empty()) {
-    string confirm = request->query ["confirm"];
+    const std::string confirm = webserver_request.query ["confirm"];
     if (confirm.empty()) {
       Dialog_Yes dialog_yes = Dialog_Yes ("book", translate("Would you like to delete this chapter?"));
       dialog_yes.add_query ("bible", bible);
-      dialog_yes.add_query ("book", convert_to_string (book));
+      dialog_yes.add_query ("book", std::to_string (book));
       dialog_yes.add_query ("deletechapter", deletechapter);
       page += dialog_yes.run ();
       return page;
     } if (confirm == "yes") {
-      if (write_access) bible_logic_delete_chapter (bible, book, convert_to_int (deletechapter));
+      if (write_access) bible_logic::delete_chapter (bible, book, filter::strings::convert_to_int (deletechapter));
     }
   }
   
   // Add chapter.
-  if (request->query.count ("createchapter")) {
+  if (webserver_request.query.count ("createchapter")) {
     Dialog_Entry dialog_entry = Dialog_Entry ("book", translate("Please enter the number for the new chapter"), "", "createchapter", "");
     dialog_entry.add_query ("bible", bible);
-    dialog_entry.add_query ("book", convert_to_string (book));
+    dialog_entry.add_query ("book", std::to_string (book));
     page += dialog_entry.run ();
     return page;
   }
-  if (request->post.count ("createchapter")) {
-    int createchapter = convert_to_int (request->post ["entry"]);
-    vector <int> chapters = request->database_bibles ()->getChapters (bible, book);
+  if (webserver_request.post.count ("createchapter")) {
+    const int createchapter = filter::strings::convert_to_int (webserver_request.post ["entry"]);
+    const std::vector <int> chapters = database::bibles::get_chapters (bible, book);
     // Only create the chapters if it does not yet exist.
     if (find (chapters.begin(), chapters.end(), createchapter) == chapters.end()) {
-      vector <string> feedback;
-      bool result = true;
-      if (write_access) result = book_create (bible, book, createchapter, feedback);
-      string message = filter_string_implode (feedback, " ");
+      std::vector <std::string> feedback{};
+      bool result {true};
+      if (write_access) result = book_create (bible, static_cast<book_id>(book), createchapter, feedback);
+      const std::string message = filter::strings::implode (feedback, " ");
       if (result) success_message = message;
       else error_message = message;
     } else {
@@ -124,17 +122,17 @@ string bible_book (void * webserver_request)
   }
   
   // Available chapters.
-  vector <int> chapters = request->database_bibles ()->getChapters (bible, book);
-  string chapterblock;
-  for (auto & chapter : chapters) {
+  const std::vector <int> chapters = database::bibles::get_chapters (bible, book);
+  std::string chapterblock {};
+  for (const auto& chapter : chapters) {
     chapterblock.append (R"(<a href="chapter?bible=)");
     chapterblock.append (bible);
     chapterblock.append ("&book=");
-    chapterblock.append (convert_to_string (book));
+    chapterblock.append (std::to_string (book));
     chapterblock.append ("&chapter=");
-    chapterblock.append (convert_to_string (chapter));
+    chapterblock.append (std::to_string (chapter));
     chapterblock.append (R"(">)");
-    chapterblock.append (convert_to_string (chapter));
+    chapterblock.append (std::to_string (chapter));
     chapterblock.append ("</a>\n");
   }
   view.set_variable ("chapterblock", chapterblock);
@@ -146,7 +144,7 @@ string bible_book (void * webserver_request)
 
   page += view.render ("bb", "book");
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   return page;
 }
