@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_CHANGES_CHANGE_H
-#define INCLUDED_CHANGES_CHANGE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string changes_change_url ();
-bool changes_change_acl (void * webserver_request);
-string changes_change (void * webserver_request);
-
-
-#endif
+std::string changes_change_url ();
+bool changes_change_acl (Webserver_Request& webserver_request);
+std::string changes_change (Webserver_Request& webserver_request);
