@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -35,16 +35,15 @@
 #include <access/bible.h>
 #include <menu/logic.h>
 #include <checks/settings.h>
-using namespace std;
 
 
-string checks_settingspairs_url ()
+std::string checks_settingspairs_url ()
 {
   return "checks/settingspairs";
 }
 
 
-bool checks_settingspairs_acl ([[maybe_unused]] void * webserver_request)
+bool checks_settingspairs_acl ([[maybe_unused]] Webserver_Request& webserver_request)
 {
 #ifdef HAVE_CLIENT
   return true;
@@ -54,12 +53,9 @@ bool checks_settingspairs_acl ([[maybe_unused]] void * webserver_request)
 }
 
 
-string checks_settingspairs (void * webserver_request)
+std::string checks_settingspairs (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  
-  string page {};
+  std::string page {};
   Assets_Header header = Assets_Header (translate ("Matching pairs"), webserver_request);
   header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   header.add_bread_crumb (checks_settings_url (), menu_logic_checks_settings_text ());
@@ -67,16 +63,16 @@ string checks_settingspairs (void * webserver_request)
   Assets_View view {};
   
   
-  string bible = access_bible::clamp (webserver_request, request->database_config_user()->getBible ());
+  const std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->getBible ());
   view.set_variable ("bible", bible);
   
   
-  if (request->post.count ("pairs")) {
-    string fragment = request->post["pairs"];
-    vector <string> errors {};
-    vector <string> pairs = filter::strings::explode (fragment, ' ');
+  if (webserver_request.post.count ("pairs")) {
+    const std::string fragment = webserver_request.post["pairs"];
+    std::vector <std::string> errors {};
+    std::vector <std::string> pairs = filter::strings::explode (fragment, ' ');
     bool okay {true};
-    for (const auto & pair : pairs) {
+    for (const auto& pair : pairs) {
       const size_t length = filter::strings::unicode_string_length (pair);
       if (length != 2) {
         errors.push_back (translate ("A pair should consist of two characters:") + " " + pair);
@@ -84,13 +80,13 @@ string checks_settingspairs (void * webserver_request)
       }
     }
     if (okay) {
-      Database_Config_Bible::setMatchingPairs (bible, fragment);
+      database::config::bible::set_matching_pairs (bible, fragment);
       view.set_variable ("success", translate("The pairs were saved"));
     } else {
       view.set_variable ("error", filter::strings::implode (errors, " | "));
     }
   }
-  view.set_variable ("pairs", Database_Config_Bible::getMatchingPairs (bible));
+  view.set_variable ("pairs", database::config::bible::get_matching_pairs (bible));
   
   
   page += view.render ("checks", "settingspairs");
