@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,14 +21,16 @@
 
 #include <config/libraries.h>
 
+class Webserver_Request;
+
 namespace checksum_logic {
 
 std::string send (const std::string & data, bool readwrite);
 std::string get (const std::string & data);
 std::string get (const std::vector <std::string>& data);
-std::string get_chapter (void * webserver_request, const std::string & bible, int book, int chapter);
-std::string get_book (void * webserver_request, const std::string & bible, int book);
-std::string get_bible (void * webserver_request, const std::string & bible);
-std::string get_bibles (void * webserver_request, const std::vector <std::string> & bibles);
+std::string get_chapter (Webserver_Request& webserver_request, const std::string & bible, int book, int chapter);
+std::string get_book (Webserver_Request& webserver_request, const std::string & bible, int book);
+std::string get_bible (Webserver_Request& webserver_request, const std::string & bible);
+std::string get_bibles (Webserver_Request& webserver_request, const std::vector <std::string> & bibles);
 
 };
