@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@
 struct Merge_Conflict
 {
 public:
-  string base {};
-  string change {};
-  string prioritized_change {};
-  string result {};
-  string subject {};
+  std::string base {};
+  std::string change {};
+  std::string prioritized_change {};
+  std::string result {};
+  std::string subject {};
   // The following shows the passage where the conflict occurred.
   int book {0};
   int chapter {0};
