@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -35,67 +35,62 @@
 #include <sendreceive/logic.h>
 #include <assets/external.h>
 #include <bb/logic.h>
-using namespace std;
 
 
-string client_index_url ()
+std::string client_index_url ()
 {
   return "client/index";
 }
 
 
-bool client_index_acl (void * webserver_request)
+bool client_index_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::member ());
 }
 
 
-void client_index_remove_all_users (void * webserver_request)
+void client_index_remove_all_users (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  vector <string> existingusers {request->database_users()->get_users ()};
-  for (const auto & existinguser : existingusers) {
-    request->database_users()->removeUser (existinguser);
+  const std::vector <std::string> existing_users {webserver_request.database_users()->get_users ()};
+  for (const auto& existing_user : existing_users) {
+    webserver_request.database_users()->removeUser (existing_user);
   }
 }
 
 
-void client_index_enable_client (void * webserver_request, const string & username, const string & password, int level)
+void client_index_enable_client (Webserver_Request& webserver_request, const std::string& username, const std::string& password, const int level)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
   // Enable client mode upon a successful connection.
   client_logic_enable_client (true);
   
   // Remove all users from the database, and add the current one.
-  client_index_remove_all_users (request);
-  request->database_users ()->add_user (username, password, level, string());
+  client_index_remove_all_users (webserver_request);
+  webserver_request.database_users ()->add_user (username, password, level, std::string());
   
   // Update the username and the level in the current session.
-  request->session_logic ()->set_username (username);
-  request->session_logic ()->currentLevel (true);
+  webserver_request.session_logic ()->set_username (username);
+  webserver_request.session_logic ()->get_level (true);
   
   // If there's pending Bible updates, send them off to the user.
   bible_logic::client_mail_pending_bible_updates (username);
   
   // Clear all pending note actions and Bible actions and settings updates.
   Database_NoteActions database_noteactions;
-  Database_BibleActions database_bibleactions;
   database_noteactions.clear ();
   database_noteactions.create ();
-  database_bibleactions.clear ();
-  database_bibleactions.create ();
-  request->session_logic ()->set_username (username);
-  request->database_config_user()->setUpdatedSettings ({});
-  Database_Config_General::setUnsentBibleDataTime (0);
-  Database_Config_General::setUnreceivedBibleDataTime (filter::date::seconds_since_epoch ());
+  database::bible_actions::clear ();
+  database::bible_actions::create ();
+  webserver_request.session_logic ()->set_username (username);
+  webserver_request.database_config_user()->setUpdatedSettings ({});
+  database::config::general::set_unsent_bible_data_time (0);
+  database::config::general::set_unreceived_bible_data_time (filter::date::seconds_since_epoch ());
   
   // Set flag for first run after connecting.
-  Database_Config_General::setJustConnectedToCloud (true);
+  database::config::general::set_just_connected_to_cloud (true);
   
   // Set it to repeat sync every so often.
-  if (Database_Config_General::getRepeatSendReceive () == 0) {
-    Database_Config_General::setRepeatSendReceive (2);
+  if (database::config::general::get_repeat_send_receive () == 0) {
+    database::config::general::set_repeat_send_receive (2);
   }
   
   // Schedule a sync operation straightaway.
@@ -103,36 +98,35 @@ void client_index_enable_client (void * webserver_request, const string & userna
 }
 
 
-string client_index (void * webserver_request)
+std::string client_index (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
   Assets_View view {};
   
-  if (request->query.count ("disable")) {
+  if (webserver_request.query.count ("disable")) {
     client_logic_enable_client (false);
-    client_index_remove_all_users (request);
-    Database_Config_General::setRepeatSendReceive (0);
-    Database_Config_General::setUnsentBibleDataTime (0);
-    Database_Config_General::setUnreceivedBibleDataTime (0);
-    Database_Config_General::setJustConnectedToCloud (false);
+    client_index_remove_all_users (webserver_request);
+    database::config::general::set_repeat_send_receive (0);
+    database::config::general::set_unsent_bible_data_time (0);
+    database::config::general::set_unreceived_bible_data_time (0);
+    database::config::general::set_just_connected_to_cloud (false);
   }
   
-  bool connect = request->post.count ("connect");
-  bool demo = request->query.count ("demo");
+  bool connect = webserver_request.post.count ("connect");
+  bool demo = webserver_request.query.count ("demo");
   if (connect || demo) {
 
     bool proceed {true};
     
-    string address {};
-    if (proceed) address = request->post ["address"];
+    std::string address {};
+    if (proceed) address = webserver_request.post ["address"];
     if (demo) address = demo_address ();
     // If there's not something like "http" in the server address, then add it.
-    if (address.find ("http") == string::npos) address = filter_url_set_scheme (address, false);
+    if (address.find ("http") == std::string::npos)
+      address = filter_url_set_scheme (address, false);
     if (proceed) {
       // Get schema, host and port.
-      string scheme {};
-      string host {};
+      std::string scheme {};
+      std::string host {};
       int port {0};
       filter_url_get_scheme_host_port (address, scheme, host, port);
       // If no address given, then that's an error.
@@ -147,27 +141,27 @@ string client_index (void * webserver_request)
       }
     }
     // Store the address.
-    Database_Config_General::setServerAddress (address);
+    database::config::general::set_server_address (address);
     
-    int port = convert_to_int (config::logic::http_network_port ());
-    if (proceed) port = convert_to_int (request->post ["port"]);
+    int port = filter::strings::convert_to_int (config::logic::http_network_port ());
+    if (proceed) port = filter::strings::convert_to_int (webserver_request.post ["port"]);
     if (demo) port = demo_port ();
     if (proceed) if (port == 0) {
       view.set_variable ("error", translate ("Supply a port number"));
       proceed = false;
     }
-    Database_Config_General::setServerPort (port);
+    database::config::general::set_server_port (port);
     
-    string user {};
-    if (proceed) user = request->post ["user"];
+    std::string user {};
+    if (proceed) user = webserver_request.post ["user"];
     if (demo) user = session_admin_credentials ();
     if (proceed) if (user.empty()) {
       view.set_variable ("error", translate ("Supply a username"));
       proceed = false;
     }
     
-    string pass {};
-    if (proceed) pass = request->post ["pass"];
+    std::string pass {};
+    if (proceed) pass = webserver_request.post ["pass"];
     if (demo) pass = session_admin_credentials ();
     if (proceed) if (pass.empty()) {
       view.set_variable ("error", translate ("Supply a password"));
@@ -175,11 +169,11 @@ string client_index (void * webserver_request)
     }
 
     if (proceed) {
-      string response = client_logic_connection_setup (user, md5 (pass));
-      int iresponse = convert_to_int (response);
+      const std::string response = client_logic_connection_setup (user, md5 (pass));
+      const int iresponse = filter::strings::convert_to_int (response);
       if ((iresponse >= Filter_Roles::guest ()) && (iresponse <= Filter_Roles::admin ())) {
         // Enable client mode upon a successful connection.
-        client_index_enable_client (request, user, pass, iresponse);
+        client_index_enable_client (webserver_request, user, pass, iresponse);
         // Feedback.
         view.set_variable ("success", translate("Connection is okay."));
       } else {
@@ -191,17 +185,17 @@ string client_index (void * webserver_request)
   if (client_logic_client_enabled ()) view.enable_zone ("clienton");
   else view.enable_zone ("clientoff");
   
-  string address {Database_Config_General::getServerAddress ()};
+  const std::string address {database::config::general::get_server_address ()};
   view.set_variable ("address", address);
   
-  int port {Database_Config_General::getServerPort ()};
-  view.set_variable ("port", convert_to_string (port));
+  const int port {database::config::general::get_server_port ()};
+  view.set_variable ("port", std::to_string (port));
   
   view.set_variable ("url", client_logic_link_to_cloud ("", ""));
   
-  vector <string> users {request->database_users ()->get_users ()};
-  for (const auto & user : users) {
-    int level = request->database_users()->get_level (user);
+  const std::vector <std::string> users {webserver_request.database_users ()->get_users ()};
+  for (const auto& user : users) {
+    const int level = webserver_request.database_users()->get_level (user);
     view.set_variable ("role", Filter_Roles::text (level));
   }
   
@@ -209,14 +203,14 @@ string client_index (void * webserver_request)
 
   view.set_variable ("external", assets_external_logic_link_addon ());
 
-  if (request->query.count ("info")) {
+  if (webserver_request.query.count ("info")) {
     view.enable_zone ("info");
   }
   
-  bool basic_mode {config::logic::basic_mode (request)};
+  const bool basic_mode {config::logic::basic_mode (webserver_request)};
   if (basic_mode) view.enable_zone("basicmode");
   
-  string page {};
+  std::string page {};
 
   // Since the role of the user may change after a successful connection to the server,
   // the menu generation in the header should be postponed till when the actual role is known.
