@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -38,137 +38,25 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <pugixml.hpp>
 #endif
 #pragma GCC diagnostic pop
-using namespace std;
-using namespace pugi;
 
 
 #ifdef HAVE_CLOUD
 
 
-Confirm_Worker::Confirm_Worker (void * webserver_request_in)
-{
-  webserver_request = webserver_request_in;
-}
-
-
-// Sets up a confirmation cycle in order to change something in the database.
-// If for example a user requests the email address to be changed, 
-// an initial email will be sent, which the user should confirm.
-// mailto            : Email address for the initial email and the response.
-// initial_subject   : The subject of the initial email message.
-// initial_body      : The body of the initial email message.
-// query             : The query to be executed on the database if the user confirms the email successfully.
-// subsequent_subject: The subject of the email to send upon user confirmation.
-// subsequent_body   : The body of the email to send upon user confirmation.
-void Confirm_Worker::setup (string mailto, string username,
-                            string initial_subject, string initial_body,
-                            string query,
-                            string subsequent_subject, string subsequent_body)
-{
-  Database_Confirm database_confirm;
-  unsigned int confirmation_id = database_confirm.get_new_id ();
-  xml_document document;
-  xml_node node = document.append_child ("p");
-  string information;
-  if (config::logic::default_bibledit_configuration ()) {
-    information = translate ("Please confirm this request by clicking this following link:");
-  }
-  node.text ().set (information.c_str());
-  node = document.append_child ("p");
-  string siteUrl = config::logic::site_url (webserver_request);
-  string confirmation_url = filter_url_build_http_query (siteUrl + session_confirm_url (), "id", to_string(confirmation_id));
-  node.text ().set (confirmation_url.c_str());
-  stringstream output;
-  document.print (output, "", format_raw);
-  initial_body += output.str ();
-  email_schedule (mailto, initial_subject, initial_body);
-  database_confirm.store (confirmation_id, query, mailto, subsequent_subject, subsequent_body, username);
-}
-
-
-// Handles a confirmation email received "from" with "subject" and "body".
-// Returns true if the mail was handled, else false.
-bool Confirm_Worker::handleEmail ([[maybe_unused]]string from, string subject, string body)
-{
-  // Find out in the confirmation database whether the subject line contains an active ID.
-  // If not, bail out.
-  Database_Confirm database_confirm;
-  unsigned int id = database_confirm.search_id (subject);
-  if (id == 0) {
-    return false;
-  }
-  // An active ID was found: Execute the associated database query.
-  string query = database_confirm.get_query (id);
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  request->database_users()->execute (query);
-  // Send confirmation mail.
-  string mailto = database_confirm.get_mail_to (id);
-  subject = database_confirm.get_subject (id);
-  body = database_confirm.get_body (id);
-  email_schedule (mailto, subject, body);
-  // Delete the confirmation record.
-  database_confirm.erase (id);
-  // Notify managers.
-  informManagers (mailto, body);
-  // Job done.
-  return true;
-}
-
-
-// Handles a confirmation link clicked with a confirmation ID.
-// Returns true if link was valid, else false.
-bool Confirm_Worker::handleLink (string & email)
-{
-  // Get the confirmation identifier from the link that was clicked.
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  string web_id = request->query["id"];
-  
-  // If the identifier was not given, the link was not handled successfully.
-  if (web_id.empty()) return false;
-
-  // Find out in the confirmation database whether the subject line contains an active ID.
-  // If not, bail out.
-  Database_Confirm database_confirm;
-  unsigned int id = database_confirm.search_id (web_id);
-  if (id == 0) {
-    return false;
-  }
- 
-  // An active ID was found: Execute the associated database query.
-  string query = database_confirm.get_query (id);
-  request->database_users()->execute (query);
-
-  // Send confirmation mail.
-  string mailto = database_confirm.get_mail_to (id);
-  string subject = database_confirm.get_subject (id);
-  string body = database_confirm.get_body (id);
-  email_schedule (mailto, subject, body);
-
-  // Delete the confirmation record.
-  database_confirm.erase (id);
-
-  // Notify managers.
-  informManagers (mailto, body);
-
-  // Pass the email address to the caller.
-  email = mailto;
-  
-  // Job done.
-  return true;
-}
+namespace confirm::worker {
 
 
 // Inform the managers about an account change.
-void Confirm_Worker::informManagers (string email, string body)
+static void inform_managers (const std::string& email, const std::string& body)
 {
-  Database_Users database_users;
-  vector <string> users = database_users.get_users ();
-  for (auto & user : users) {
-    int level = database_users.get_level (user);
+  Database_Users database_users {};
+  const std::vector <std::string>& users = database_users.get_users ();
+  for (const auto& user : users) {
+    const int level = database_users.get_level (user);
     if (level >= Filter_Roles::manager ()) {
-      string mailto = database_users.get_email (user);
-      string subject = translate ("User account change");
-      string newbody = translate ("A user account was changed.");
+      const std::string mailto = database_users.get_email (user);
+      const std::string subject = translate ("User account change");
+      std::string newbody = translate ("A user account was changed.");
       newbody.append (" ");
       newbody.append (translate ("Email address:"));
       newbody.append (" ");
@@ -183,4 +71,84 @@ void Confirm_Worker::informManagers (string email, string body)
 }
 
 
+// Sets up a confirmation cycle in order to change something in the database.
+// If for example a user requests the email address to be changed,
+// an initial email will be sent, which the user should confirm.
+// mailto            : Email address for the initial email and the response.
+// initial_subject   : The subject of the initial email message.
+// initial_body      : The body of the initial email message.
+// query             : The query to be executed on the database if the user confirms the email successfully.
+// subsequent_subject: The subject of the email to send upon user confirmation.
+// subsequent_body   : The body of the email to send upon user confirmation.
+void setup (Webserver_Request& webserver_request,
+            const std::string& mailto, const std::string& username,
+            const std::string& initial_subject, std::string initial_body,
+            const std::string& query,
+            const std::string& subsequent_subject, const std::string& subsequent_body)
+{
+  const unsigned int confirmation_id = database::confirm::get_new_id ();
+  pugi::xml_document document;
+  pugi::xml_node node = document.append_child ("p");
+  std::string information;
+  if (config::logic::default_bibledit_configuration ()) {
+    information = translate ("Please confirm this request by clicking this following link:");
+  }
+  node.text ().set (information.c_str());
+  node = document.append_child ("p");
+  const std::string site_url = config::logic::site_url (webserver_request);
+  std::string confirmation_url = filter_url_build_http_query (site_url + session_confirm_url (), "id", std::to_string(confirmation_id));
+  node.text ().set (confirmation_url.c_str());
+  std::stringstream output;
+  document.print (output, "", pugi::format_raw);
+  initial_body.append (output.str ());
+  email_schedule (mailto, initial_subject, initial_body);
+  database::confirm::store (confirmation_id, query, mailto, subsequent_subject, subsequent_body, username);
+}
+
+
+// Handles a confirmation link clicked with a confirmation ID.
+// Returns true if link was valid, else false.
+bool handle_link (Webserver_Request& webserver_request, std::string& email)
+{
+  // Get the confirmation identifier from the link that was clicked.
+  const std::string web_id = webserver_request.query["id"];
+  
+  // If the identifier was not given, the link was not handled successfully.
+  if (web_id.empty()) 
+    return false;
+  
+  // Find out from the confirmation database whether the subject line contains an active ID.
+  // If not, bail out.
+  const unsigned int id = database::confirm::search_id (web_id);
+  if (id == 0) {
+    return false;
+  }
+  
+  // An active ID was found: Execute the associated database query.
+  const std::string query = database::confirm::get_query (id);
+  webserver_request.database_users()->execute (query);
+  
+  // Send confirmation mail.
+  const std::string mailto = database::confirm::get_mail_to (id);
+  const std::string subject = database::confirm::get_subject (id);
+  const std::string body = database::confirm::get_body (id);
+  email_schedule (mailto, subject, body);
+  
+  // Delete the confirmation record.
+  database::confirm::erase (id);
+  
+  // Notify the manager(s).
+  confirm::worker::inform_managers (mailto, body);
+  
+  // Pass the email address to the caller.
+  email = mailto;
+  
+  // Job done.
+  return true;
+}
+
+
+} // namespace.
+
+
 #endif
