@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,21 +21,20 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
+class Webserver_Request;
+
 #ifdef HAVE_CLOUD
 
-class Confirm_Worker
-{
-public:
-  Confirm_Worker (void * webserver_request_in);
-  void setup (std::string mailto, std::string username,
-              std::string initial_subject, std::string initial_body,
-              std::string query,
-              std::string subsequent_subject, std::string subsequent_body);
-  bool handleEmail (std::string from, std::string subject, std::string body);
-  bool handleLink (std::string & email);
-private:
-  void * webserver_request {nullptr};
-  void informManagers (std::string email, std::string body);
-};
+namespace confirm::worker {
+
+void setup (Webserver_Request& webserver_request,
+            const std::string& mailto, const std::string& username,
+            const std::string& initial_subject, std::string initial_body,
+            const std::string& query,
+            const std::string& subsequent_subject, const std::string& subsequent_body);
+
+bool handle_link (Webserver_Request& webserver_request, std::string& email);
+
+}
 
 #endif
