@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -43,5 +43,5 @@ private:
   std::string resourceFolder (const std::string& name);
   std::string imagePath (std::string name, std::string image);
   std::string databaseFile ();
-  sqlite3 * connect (std::string name);
+  std::string database_path (const std::string& name);
 };
