@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -39,6 +39,4 @@ public:
   std::string get_progress (int id);
   void set_result (int id, std::string result);
   std::string get_result (int id);
-private:
-  sqlite3 * connect ();
 };
