@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,31 +17,25 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_OSHB_H
-#define INCLUDED_DATABASE_OSHB_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/passage.h>
 
-
 class Database_OsHb
 {
 public:
   void create ();
   void optimize ();
-  vector <string> getVerse (int book, int chapter, int verse);
-  vector <Passage> searchHebrew (string hebrew);
-  void store (int book, int chapter, int verse, string lemma, string word, string morph);
-  vector <int> rowids (int book, int chapter, int verse);
-  string lemma (int rowid);
-  string word (int rowid);
-  string morph (int rowid);
+  std::vector <std::string> getVerse (int book, int chapter, int verse);
+  std::vector <Passage> searchHebrew (std::string hebrew);
+  void store (int book, int chapter, int verse, std::string lemma, std::string word, std::string morph);
+  std::vector <int> rowids (int book, int chapter, int verse);
+  std::string lemma (int rowid);
+  std::string word (int rowid);
+  std::string morph (int rowid);
 private:
   const char * filename ();
-  int get_id (const char * table_row, string item);
-  string get_item (const char * item, int rowid);
+  int get_id (const char * table_row, std::string item);
+  std::string get_item (const char * item, int rowid);
 };
-
-
-#endif
