@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,21 +17,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_STRONG_H
-#define INCLUDED_DATABASE_STRONG_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Strong
 {
 public:
-  string definition (string strong);
-  vector <string> strong (string lemma);
-private:
-  sqlite3 * connect ();
+  std::string definition (std::string strong);
+  std::vector <std::string> strong (std::string lemma);
 };
-
-
-#endif
