@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include <filter/usfm.h>
 #include <filter/url.h>
 #include <filter/string.h>
-#include <filter/indonesian.h>
 #include <database/config/general.h>
 #include <database/config/bible.h>
 #include <database/logs.h>
@@ -46,6 +45,7 @@
 #include <lexicon/logic.h>
 #include <search/logic.h>
 #include <book/create.h>
+#include <setup/logic.h>
 
 
 /*
@@ -71,9 +71,9 @@
 
 
 // Returns true if the credentials are correct for a demo installation.
-bool demo_acl (string user, string pass)
+bool demo_acl (std::string user, std::string pass)
 {
-  if (config_logic_demo_enabled ()) {
+  if (config::logic::demo_enabled ()) {
     if (user == session_admin_credentials ()) {
       if ((pass == session_admin_credentials ()) || (pass == md5 (session_admin_credentials ()))) {
         return true;
@@ -84,39 +84,14 @@ bool demo_acl (string user, string pass)
 }
 
 
-// Returns the address of the current demo server.
-string demo_address ()
-{
-  return "http://bibledit.org";
-}
-
-
-string demo_address_secure ()
-{
-  return "https://bibledit.org";
-}
-
-
-int demo_port ()
-{
-  return 8090;
-}
-
-
-int demo_port_secure ()
-{
-  return 8091;
-}
-
-
 // Returns a warning in case the client is connected to the open demo server.
-string demo_client_warning ()
+std::string demo_client_warning ()
 {
-  string warning;
+  std::string warning {};
   if (client_logic_client_enabled ()) {
-    string address = Database_Config_General::getServerAddress ();
+    std::string address = database::config::general::get_server_address ();
     if (address == demo_address () || address == demo_address_secure ()) {
-      int port = Database_Config_General::getServerPort ();
+      int port = database::config::general::get_server_port ();
       if (port == demo_port () || port == demo_port_secure ()) {
         warning.append (translate("You are connected to a public demo of Bibledit Cloud."));
         warning.append (" ");
@@ -136,101 +111,101 @@ void demo_clean_data ()
   Database_Logs::log ("Cleaning up the demo data");
   
   
-  Webserver_Request request;
+  Webserver_Request webserver_request {};
   
   
-  // Set user to the demo credentials (admin) as this is the user who is always logged-in in a demo installation.
-  request.session_logic ()->set_username (session_admin_credentials ());
+  // Set user to the demo credentials (admin).
+  // This is the user who is always logged-in in a demo installation.
+  webserver_request.session_logic ()->set_username (session_admin_credentials ());
   
   
   // Delete empty stylesheet that may have been there.
-  request.database_styles()->revokeWriteAccess ("", styles_logic_standard_sheet ());
-  request.database_styles()->deleteSheet ("");
+  webserver_request.database_styles()->revokeWriteAccess ("", styles_logic_standard_sheet ());
+  webserver_request.database_styles()->deleteSheet ("");
   styles_sheets_create_all ();
   
   
   // Set both stylesheets to "Standard" for all Bibles.
-  vector <string> bibles = request.database_bibles()->getBibles ();
-  for (auto & bible : bibles) {
-    Database_Config_Bible::setExportStylesheet (bible, styles_logic_standard_sheet ());
-    Database_Config_Bible::setEditorStylesheet (bible, styles_logic_standard_sheet ());
+  std::vector <std::string> bibles = database::bibles::get_bibles ();
+  for (const auto & bible : bibles) {
+    database::config::bible::set_export_stylesheet (bible, styles_logic_standard_sheet ());
+    database::config::bible::set_editor_stylesheet (bible, styles_logic_standard_sheet ());
   }
   
   
+  // Regenerate versification databases.
+  setup_generate_versification_databases ();
+
+  
   // Set the site language to "Default"
-  Database_Config_General::setSiteLanguage ("");
+  database::config::general::set_site_language (std::string());
 
 
   // Ensure the default users are there.
-  map <string, int> users = {
-    pair ("guest", Filter_Roles::guest ()),
-    pair ("member", Filter_Roles::member ()),
-    pair ("consultant", Filter_Roles::consultant ()),
-    pair ("translator", Filter_Roles::translator ()),
-    pair ("manager", Filter_Roles::manager ()),
-    pair (session_admin_credentials (), Filter_Roles::admin ())
+  std::map <std::string, int> users = {
+    std::pair ("guest", Filter_Roles::guest ()),
+    std::pair ("member", Filter_Roles::member ()),
+    std::pair ("consultant", Filter_Roles::consultant ()),
+    std::pair ("translator", Filter_Roles::translator ()),
+    std::pair ("manager", Filter_Roles::manager ()),
+    std::pair (session_admin_credentials (), Filter_Roles::admin ())
   };
-  for (auto & element : users) {
-    if (!request.database_users ()->usernameExists (element.first)) {
-      request.database_users ()->add_user(element.first, element.first, element.second, "");
+  for (const auto & element : users) {
+    if (!webserver_request.database_users ()->usernameExists (element.first)) {
+      webserver_request.database_users ()->add_user(element.first, element.first, element.second, "");
     }
-    request.database_users ()->set_level (element.first, element.second);
+    webserver_request.database_users ()->set_level (element.first, element.second);
   }
   
   
   // Create / update sample Bible.
-  if (config_logic_default_bibledit_configuration ()) {
+  if (config::logic::default_bibledit_configuration ()) {
     demo_create_sample_bible ();
   }
 
 
   // Create sample notes.
-  if (config_logic_default_bibledit_configuration ()) {
-    demo_create_sample_notes (&request);
+  if (config::logic::default_bibledit_configuration ()) {
+    demo_create_sample_notes (webserver_request);
   }
 
-  
+
   // Create samples for the workspaces.
-  if (config_logic_default_bibledit_configuration ()) {
-    demo_create_sample_workspaces (&request);
+  if (config::logic::default_bibledit_configuration ()) {
+    demo_create_sample_workspaces (webserver_request);
   }
   
   
   // Set navigator to John 3:16.
-  if (config_logic_default_bibledit_configuration ()) {
-    Ipc_Focus::set (&request, 43, 3, 16);
+  if (config::logic::default_bibledit_configuration ()) {
+    Ipc_Focus::set (webserver_request, 43, 3, 16);
   }
 
 
-  // Indonesian Cloud Free
-  // Set navigator to John 1:1.
-  if (config_logic_indonesian_cloud_free_simple ()) {
-    Ipc_Focus::set (&request, 43, 1, 1);
-  }
-  
-  
   // Set and/or trim resources to display.
   // Too many resources crash the demo: Limit the amount.
-  vector <string> resources = request.database_config_user()->getActiveResources ();
-  bool reset_resources = false;
-  if (resources.size () > 25) reset_resources = true;
-  vector <string> defaults = demo_logic_default_resources ();
-  for (auto & name : defaults) {
+  std::vector <std::string> resources = webserver_request.database_config_user()->getActiveResources ();
+  bool reset_resources {false};
+  size_t max_resource {25};
+  if (resources.size () > max_resource) reset_resources = true;
+  // Check if all the current resource exists in the default.
+  std::vector <std::string> defaults = demo_logic_default_resources ();
+  for (const auto & name : defaults) {
     if (!in_array (name, resources)) reset_resources = true;
   }
   if (reset_resources) {
     resources = demo_logic_default_resources ();
-    request.database_config_user()->setActiveResources (resources);
+    webserver_request.database_config_user()->setActiveResources (resources);
   }
   
   
   // No flipped basic <> advanded mode.
-  request.database_config_user ()->setBasicInterfaceMode (false);
+  webserver_request.database_config_user ()->setBasicInterfaceMode (false);
 }
 
 
 // The name of the sample Bible.
-string demo_sample_bible_name ()
+std::string demo_sample_bible_name ()
 {
   return "Sample";
 }
@@ -244,17 +219,17 @@ void demo_create_sample_bible ()
   Database_Logs::log ("Creating sample Bible");
   
   // Remove and create the sample Bible.
-  Database_Bibles database_bibles;
-  database_bibles.deleteBible (demo_sample_bible_name ());
-  database_bibles.createBible (demo_sample_bible_name ());
+  database::bibles::delete_bible (demo_sample_bible_name ());
+  database::bibles::create_bible (demo_sample_bible_name ());
   
   // Remove index for the sample Bible.
   search_logic_delete_bible (demo_sample_bible_name ());
 
   // Copy the sample Bible data and search index into place.
-  vector <int> rowids = Database_Sample::get ();
+  std::vector <int> rowids = Database_Sample::get ();
   for (auto rowid : rowids) {
-    string file, data;
+    std::string file {};
+    std::string data {};
     Database_Sample::get (rowid, file, data);
     // Remove the "./" from the start.
     file.erase (0, 2);
@@ -267,13 +242,13 @@ void demo_create_sample_bible ()
     // * it means that Bibledit uses a different name for the Sample Bible,
     // * and the file needs an update.
     size_t pos = file.find(demo_sample_bible_name());
-    if (pos == string::npos) {
-      string filename = "Sample";
-      file = filter_string_str_replace(filename, demo_sample_bible_name(), file);
+    if (pos == std::string::npos) {
+      std::string filename = "Sample";
+      file = filter::strings::replace(filename, demo_sample_bible_name(), file);
     }
     // Proceed with the path.
     file = filter_url_create_root_path ({file});
-    string path = filter_url_dirname (file);
+    std::string path = filter_url_dirname (file);
     if (!file_or_dir_exists (path)) filter_url_mkdir (path);
     filter_url_file_put_contents (file, data);
   }
@@ -288,46 +263,44 @@ void demo_create_sample_bible ()
 // This way it is fast even on low power devices.
 void demo_prepare_sample_bible ()
 {
-  Database_Bibles database_bibles;
   Database_Sample::create ();
   // Remove the sample Bible plus all related data.
-  database_bibles.deleteBible (demo_sample_bible_name ());
+  database::bibles::delete_bible (demo_sample_bible_name ());
   search_logic_delete_bible (demo_sample_bible_name ());
   // Create a new sample Bible.
-  database_bibles.createBible (demo_sample_bible_name ());
+  database::bibles::create_bible (demo_sample_bible_name ());
   // Location of the source USFM files for the sample Bible.
-  string directory = filter_url_create_root_path ({"demo"});
-  vector <string> files = filter_url_scandir (directory);
+  std::string directory = filter_url_create_root_path ({"demo"});
+  std::vector <std::string> files = filter_url_scandir (directory);
   for (auto file : files) {
     // Process only USFM files, skipping others.
     if (filter_url_get_extension (file) == "usfm") {
-      cout << file << endl;
       // Read the USFM and clean it up.
       file = filter_url_create_path ({directory, file});
-      string usfm = filter_url_file_get_contents (file);
-      usfm = filter_string_collapse_whitespace (usfm);
+      std::string usfm = filter_url_file_get_contents (file);
+      usfm = filter::strings::collapse_whitespace (usfm);
       // Import the USFM into the sample Bible.
-      vector <filter::usfm::BookChapterData> book_chapter_data = filter::usfm::usfm_import (usfm, styles_logic_standard_sheet ());
-      for (auto data : book_chapter_data) {
+      std::vector <filter::usfm::BookChapterData> book_chapter_data = filter::usfm::usfm_import (usfm, styles_logic_standard_sheet ());
+      for (const auto & data : book_chapter_data) {
         int book = data.m_book;
         if (book) {
           // There is license information at the top of each USFM file.
           // This results in a book with number 0.
           // This book gets skipped here, so the license information is skipped as well.
-          int chapter = data.m_chapter;
-          string usfm2 = data.m_data;
-          bible_logic_store_chapter (demo_sample_bible_name (), book, chapter, usfm2);
+          int chapter {data.m_chapter};
+          std::string usfm2 {data.m_data};
+          bible_logic::store_chapter (demo_sample_bible_name (), book, chapter, usfm2);
         }
       }
     }
   }
   // Copy the Bible data to the sample database.
-  directory = database_bibles.bibleFolder (demo_sample_bible_name ());
+  directory = database::bibles::bible_folder (demo_sample_bible_name ());
   files.clear ();
   filter_url_recursive_scandir (directory, files);
-  for (auto file : files) {
+  for (const auto & file : files) {
     if (!filter_url_is_dir (file)) {
-      string data = filter_url_file_get_contents (file);
+      std::string data = filter_url_file_get_contents (file);
       Database_Sample::store (file, data);
     }
   }
@@ -335,14 +308,14 @@ void demo_prepare_sample_bible ()
   directory = search_logic_index_folder ();
   files.clear ();
   filter_url_recursive_scandir (directory, files);
-  for (auto file : files) {
-    if (file.find (demo_sample_bible_name ()) != string::npos) {
-      string data = filter_url_file_get_contents (file);
+  for (const auto & file : files) {
+    if (file.find (demo_sample_bible_name ()) != std::string::npos) {
+      std::string data = filter_url_file_get_contents (file);
       Database_Sample::store (file, data);
     }
   }
   // The sample Bible is now in the standard location and editable by the users: Remove it.
-  database_bibles.deleteBible (demo_sample_bible_name ());
+  database::bibles::delete_bible (demo_sample_bible_name ());
   // Same for the search index.
   search_logic_delete_bible (demo_sample_bible_name ());
   // Clean up the remaining artifacts that were created along the way.
@@ -356,33 +329,31 @@ void demo_prepare_sample_bible ()
 
 
 // Create sample notes.
-void demo_create_sample_notes (void * webserver_request)
+void demo_create_sample_notes (Webserver_Request& webserver_request)
 {
   Database_Notes database_notes (webserver_request);
-  vector <int> identifiers = database_notes.get_identifiers ();
+  std::vector <int> identifiers = database_notes.get_identifiers ();
   if (identifiers.size () < 10) {
     for (int i = 1; i <= 10; i++) {
-      database_notes.store_new_note (demo_sample_bible_name (), i, i, i, "Sample Note " + convert_to_string (i), "Sample Contents for note " + convert_to_string (i), false);
+      database_notes.store_new_note (demo_sample_bible_name (), i, i, i, "Sample Note " + std::to_string (i), "Sample Contents for note " + std::to_string (i), false);
     }
   }
 }
 
 
-string demo_workspace ()
+std::string demo_workspace ()
 {
   return "Translation";
 }
 
 
-void demo_create_sample_workspaces (void * webserver_request)
+void demo_create_sample_workspaces (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  map <int, string> urls;
-  map <int, string> widths;
+  std::map <int, std::string> urls {};
+  std::map <int, std::string> widths {};
   for (int i = 0; i < 15; i++) {
-    string url;
-    string width;
+    std::string url {};
+    std::string width {};
     if (i == 0) {
       url = editusfm_index_url ();
       width = "45%";
@@ -394,98 +365,43 @@ void demo_create_sample_workspaces (void * webserver_request)
     urls [i] = url;
     widths [i] = width;
   }
-  map <int, string> row_heights = {
-    pair (0, "90%"),
-    pair (1, ""),
-    pair (2, "")
+  std::map <int, std::string> row_heights = {
+    std::pair (0, "90%"),
+    std::pair (1, ""),
+    std::pair (2, "")
   };
   
-  request->database_config_user()->setActiveWorkspace ("USFM");
-  workspace_set_urls (request, urls);
-  workspace_set_widths (request, widths);
-  workspace_set_heights (request, row_heights);
+  webserver_request.database_config_user()->setActiveWorkspace ("USFM");
+  workspace_set_urls (webserver_request, urls);
+  workspace_set_widths (webserver_request, widths);
+  workspace_set_heights (webserver_request, row_heights);
   
   urls[0] = editone2_index_url ();
   urls[1] = resource_index_url ();
   
-  request->database_config_user()->setActiveWorkspace (demo_workspace ());
-  workspace_set_urls (request, urls);
-  workspace_set_widths (request, widths);
-  workspace_set_heights (request, row_heights);
+  webserver_request.database_config_user()->setActiveWorkspace (demo_workspace ());
+  workspace_set_urls (webserver_request, urls);
+  workspace_set_widths (webserver_request, widths);
+  workspace_set_heights (webserver_request, row_heights);
 }
 
 
-vector <string> demo_logic_default_resources ()
+std::vector <std::string> demo_logic_default_resources ()
 {
-  vector <string> resources;
-  if (config_logic_default_bibledit_configuration ()) {
+  std::vector <std::string> resources {};
+  if (config::logic::default_bibledit_configuration ()) {
     // Add a few resources that are also safe in an obfuscated version.
     resources = {
       demo_sample_bible_name (),
       resource_logic_violet_divider ()
     };
     // For demo purposes, add some more resources to show-case some of the capabilities.
-    if (config_logic_demo_enabled ()) {
+    if (config::logic::demo_enabled ()) {
       resources.push_back (resource_external_biblehub_interlinear_name ());
       resources.push_back (resource_external_net_bible_name ());
       resources.push_back (SBLGNT_NAME);
     }
   }
-  // Add specific resources for Indonesian Cloud Free Simple/Demo version.
-  if (config_logic_indonesian_cloud_free_simple ()) {
-    resources.clear ();
-    resources = {
-      // Original language resources.
-      resource_logic_assemble_rich_divider ("Bahasa Sumber Alkitab", "https://alkitabkita.info/bahasa-sumber-alkitab/", "black", "orange"),
-      resource_external_biblehub_interlinear_name (),
-      HEBREW_ETCBC4_NAME,
-      OSHB_NAME,
-      "[CrossWire] *[LXX] (2.5) - Septuagint, Morphologically Tagged Rahlfs'",
-      "BYZ",
-      SBLGNT_NAME,
-      "Comparative Byz",
-      // Literal translations resources.
-      resource_logic_assemble_rich_divider ("Terjemahan Secara Harfiah", "https://alkitabkita.info/terjemahan-secara-harfiah/", "black", "orange"),
-      "MILT",
-      "TB74",
-      "KSI",
-      "AYT",
-      "Majority TCENT",
-      "1599 Geneva Bible (GNV)",
-      KJV_LEXICON_NAME,
-      "ESV",
-      "HCSB 2003",
-      // Modified literal translations resources.
-      resource_logic_assemble_rich_divider ("Terjemahan Harfian yang Dimodifikasi", "https://alkitabkita.info/terjemahan-harfiah-yang-dimodifikasi/", "black", "orange"),
-      "NET Bible",
-      "New International Version (NIV)",
-      "Expanded Bible (EXB)",
-      "International Standard Version (ISV)",
-      "FBV",
-      "Complete Jewish Bible (CJB)",
-      "GOD’S WORD Translation (GW)",
-      // Dynamic equivalence translations resources.
-      resource_logic_assemble_rich_divider ("Terjemahan Berdasarkan Arti", "https://alkitabkita.info/terjemahan-berdasarkan-arti/", "black", "orange"),
-      "AlkitabKita",
-      "BIS85",
-      "TMV87",
-      "New Living Translation (NLT)",
-      "UDB",
-      "GNT",
-      "FBV-Feb2022",
-      // Parafrase translations resources.
-      resource_logic_assemble_rich_divider ("Terjemahan Parafrasa", "https://alkitabkita.info/terjemahan-parafrasa/", "black", "orange"),
-      "FAYH",
-      "J.B. Phillips New Testament (PHILLIPS)",
-      "Living Bible (TLB)",
-      // Commentaries.
-      resource_logic_assemble_rich_divider ("Tafsiran", "https://alkitabkita.info/tafsiran/", "black", "orange"),
-      "T4T",
-      "Barnes' Notes on the Whole Bible (studylight-eng/bnb)",
-      "Dr. Constable's Expository Notes (studylight-eng/dcc)",
-      resource_logic_assemble_rich_divider ("Komentar Alkitab Gratis oleh Dr. Bob Utley", "https://www.freebiblecommentary.org/indonesian_bible_study.htm", "black", "darkseagreen"),
-    };
-  }
   // Done.
   return resources;
 }
