@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -20,17 +20,18 @@
 #pragma once
 
 #include <config/libraries.h>
+#include <assets/view.h>
 
 class Dialog_Color
 {
 public:
-  Dialog_Color (string url, string question);
+  Dialog_Color (std::string url, std::string question);
   ~Dialog_Color ();
   Dialog_Color(const Dialog_Color&) = delete;
   Dialog_Color operator=(const Dialog_Color&) = delete;
-  void add_query (string parameter, string value);
-  string run ();
+  void add_query (std::string parameter, std::string value);
+  std::string run ();
 private:
-  void * assets_view {nullptr};
-  string base_url {};
+  Assets_View assets_view {};
+  std::string base_url {};
 };
