@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #pragma once
 
 #include <config/libraries.h>
+#include <assets/view.h>
 
 class Dialog_List
 {
@@ -32,7 +33,7 @@ public:
   void add_row (std::string text, std::string parameter, std::string value);
   std::string run ();
 private:
-  void * assets_view {nullptr};
+  Assets_View assets_view {};
   std::string base_url {};
   std::string list_block {};
   bool post_result {false};
