@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <config/libraries.h>
 
-string edit_index_url ();
-bool edit_index_acl (void * webserver_request);
-string edit_index (void * webserver_request);
+class Webserver_Request;
+
+std::string edit_index_url ();
+bool edit_index_acl (Webserver_Request& webserver_request);
+std::string edit_index (Webserver_Request& webserver_request);
