@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_EDIT_PREVIEW_H
-#define INCLUDED_EDIT_PREVIEW_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string edit_preview_url ();
-bool edit_preview_acl (void * webserver_request);
-string edit_preview (void * webserver_request);
-
-
-#endif
+std::string edit_preview_url ();
+bool edit_preview_acl (Webserver_Request& webserver_request);
+std::string edit_preview (Webserver_Request& webserver_request);
