@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -42,69 +42,68 @@
 #include <sendreceive/logic.h>
 
 
-string edit_save_url ()
+std::string edit_save_url ()
 {
   return "edit/save";
 }
 
 
-bool edit_save_acl (void * webserver_request)
+bool edit_save_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string edit_save (void * webserver_request)
+std::string edit_save (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  bool post_complete = (request->post.count ("bible") && request->post.count ("book") && request->post.count ("chapter") && request->post.count ("html") && request->post.count ("checksum"));
+  bool post_complete = (webserver_request.post.count ("bible") && webserver_request.post.count ("book") && webserver_request.post.count ("chapter") && webserver_request.post.count ("html") && webserver_request.post.count ("checksum"));
   if (!post_complete) {
     return translate("Insufficient information");
   }
 
-  string bible = request->post["bible"];
-  int book = convert_to_int (request->post["book"]);
-  int chapter = convert_to_int (request->post["chapter"]);
-  string html = request->post["html"];
-  string checksum = request->post["checksum"];
-  string unique_id = request->post ["id"];
+  std::string bible = webserver_request.post["bible"];
+  int book = filter::strings::convert_to_int (webserver_request.post["book"]);
+  int chapter = filter::strings::convert_to_int (webserver_request.post["chapter"]);
+  std::string html = webserver_request.post["html"];
+  std::string checksum = webserver_request.post["checksum"];
+  std::string unique_id = webserver_request.post ["id"];
 
-  if (Checksum_Logic::get (html) != checksum) {
-    request->response_code = 409;
+  if (checksum_logic::get (html) != checksum) {
+    webserver_request.response_code = 409;
     return translate("Checksum error");
   }
 
   html = filter_url_tag_to_plus (html);
-  html = filter_string_trim (html);
+  html = filter::strings::trim (html);
 
   if (html.empty ()) {
     Database_Logs::log (translate ("There was no text.") + " " + translate ("Nothing was saved.") + " " + translate ("The original text of the chapter was reloaded."));
     return translate("Nothing to save");
   }
 
-  if (!unicode_string_is_valid (html)) {
+  if (!filter::strings::unicode_string_is_valid (html)) {
     Database_Logs::log ("The text was not valid Unicode UTF-8. The chapter could not saved and has been reverted to the last good version.");
     return translate("Save failure");
   }
   
-  if (!AccessBible::BookWrite (request, string(), bible, book)) {
+  if (!access_bible::book_write (webserver_request, std::string(), bible, book)) {
     return translate("No write access");
   }
 
-  string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
+  const std::string stylesheet = database::config::bible::get_editor_stylesheet (bible);
   
   Editor_Html2Usfm editor_export;
   editor_export.load (html);
   editor_export.stylesheet (stylesheet);
   editor_export.run ();
-  string user_usfm = editor_export.get ();
+  std::string user_usfm = editor_export.get ();
   
-  string ancestor_usfm = getLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
+  std::string ancestor_usfm = getLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
   
-  vector <filter::usfm::BookChapterData> book_chapter_text = filter::usfm::usfm_import (user_usfm, stylesheet);
+  std::vector <filter::usfm::BookChapterData> book_chapter_text = filter::usfm::usfm_import (user_usfm, stylesheet);
   if (book_chapter_text.size () != 1) {
     Database_Logs::log (translate ("User tried to save something different from exactly one chapter."));
     return translate("Incorrect chapter");
@@ -115,22 +114,22 @@ string edit_save (void * webserver_request)
   user_usfm = book_chapter_text[0].m_data;
   bool chapter_ok = (((book_number == book) || (book_number == 0)) && (chapter_number == chapter));
   if (!chapter_ok) {
-    return translate("Incorrect chapter") + " " + convert_to_string (chapter_number);
+    return translate("Incorrect chapter") + " " + std::to_string (chapter_number);
   }
   
   // Collect some data about the changes for this user
   // and for a possible merge of the user's data with the server's data.
-  string username = request->session_logic()->currentUser ();
-  [[maybe_unused]] int oldID = request->database_bibles()->getChapterId (bible, book, chapter);
-  string server_usfm = request->database_bibles()->getChapter (bible, book, chapter);
-  string newText = user_usfm;
-  string oldText = ancestor_usfm;
+  const std::string& username = webserver_request.session_logic ()->get_username ();
+  [[maybe_unused]] int oldID = database::bibles::get_chapter_id (bible, book, chapter);
+  std::string server_usfm = database::bibles::get_chapter (bible, book, chapter);
+  std::string newText = user_usfm;
+  std::string oldText = ancestor_usfm;
   
   // Safekeep the USFM to save for later.
-  string change = user_usfm;
+  std::string change = user_usfm;
   
   // Merge if the ancestor is there and differs from what's in the database.
-  vector <Merge_Conflict> conflicts;
+  std::vector <Merge_Conflict> conflicts;
   if (!ancestor_usfm.empty ()) {
     if (server_usfm != ancestor_usfm) {
       // Prioritize the user's USFM.
@@ -141,7 +140,7 @@ string edit_save (void * webserver_request)
   
   // Check on the merge.
   filter_merge_add_book_chapter (conflicts, book, chapter);
-  bible_logic_merge_irregularity_mail ({username}, conflicts);
+  bible_logic::merge_irregularity_mail ({username}, conflicts);
   
   // Check whether the USFM on disk has changed compared to the USFM that was loaded in the editor.
   // If there's a difference, email the user.
@@ -152,24 +151,23 @@ string edit_save (void * webserver_request)
   // Because the user's editor may not yet have loaded this updated Bible text.
   // https://github.com/bibledit/cloud/issues/340
   if (ancestor_usfm != server_usfm) {
-    bible_logic_recent_save_email (bible, book, chapter, username, ancestor_usfm, server_usfm);
+    bible_logic::recent_save_email (bible, book, chapter, username, ancestor_usfm, server_usfm);
   }
 
   // Safely store the chapter.
-  string explanation;
-  string message = filter::usfm::safely_store_chapter (request, bible, book, chapter, user_usfm, explanation);
-  bible_logic_unsafe_save_mail (message, explanation, username, user_usfm, book, chapter);
+  std::string explanation;
+  std::string message = filter::usfm::safely_store_chapter (webserver_request, bible, book, chapter, user_usfm, explanation);
+  bible_logic::unsafe_save_mail (message, explanation, username, user_usfm, book, chapter);
 
   // If an error message was given, then return that message to the browser.
   if (!message.empty ()) return message;
 
   // In server configuration, store details for the user's changes.
 #ifdef HAVE_CLOUD
-  int newID = request->database_bibles()->getChapterId (bible, book, chapter);
-  Database_Modifications database_modifications;
-  database_modifications.recordUserSave (username, bible, book, chapter, oldID, oldText, newID, newText);
+  int newID = database::bibles::get_chapter_id (bible, book, chapter);
+  database::modifications::recordUserSave (username, bible, book, chapter, oldID, oldText, newID, newText);
   if (sendreceive_git_repository_linked (bible)) {
-    Database_Git::store_chapter (username, bible, book, chapter, oldText, newText);
+    database::git::store_chapter (username, bible, book, chapter, oldText, newText);
   }
   rss_logic_schedule_update (username, bible, book, chapter, oldText, newText);
 #endif
@@ -185,18 +183,18 @@ string edit_save (void * webserver_request)
   editor_usfm2html.load (user_usfm);
   editor_usfm2html.stylesheet (stylesheet);
   editor_usfm2html.run ();
-  string converted_html = editor_usfm2html.get ();
+  std::string converted_html = editor_usfm2html.get ();
   // Convert to XML for comparison.
   // Remove spaces before comparing.
   // Goal: Entering a space in the editor does not cause a reload.
-  html = html2xml (html);
-  html = filter_string_str_replace (" ", "", html);
-  html = filter_string_str_replace (unicode_non_breaking_space_entity (), "", html);
-  filter_string_replace_between (html, "<", ">", "");
-  converted_html = html2xml (converted_html);
-  converted_html = filter_string_str_replace (" ", "", converted_html);
-  converted_html = filter_string_str_replace (unicode_non_breaking_space_entity (), "", converted_html);
-  filter_string_replace_between (converted_html, "<", ">", "");
+  html = filter::strings::html2xml (html);
+  html = filter::strings::replace (" ", "", html);
+  html = filter::strings::replace (filter::strings::unicode_non_breaking_space_entity (), "", html);
+  filter::strings::replace_between (html, "<", ">", "");
+  converted_html = filter::strings::html2xml (converted_html);
+  converted_html = filter::strings::replace (" ", "", converted_html);
+  converted_html = filter::strings::replace (filter::strings::unicode_non_breaking_space_entity (), "", converted_html);
+  filter::strings::replace_between (converted_html, "<", ">", "");
   // If round trip conversion differs, send a known string to the browser,
   // to signal the browser to reload the reformatted chapter.
   if (html != converted_html) return locale_logic_text_reformat ();
