@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,41 +24,36 @@
 #include <webserver/request.h>
 #include <editor/styles.h>
 #include <access/bible.h>
-using namespace std;
 
 
-string editor_style_url ()
+std::string editor_style_url ()
 {
   return "editor/style";
 }
 
 
-bool editor_style_acl (void * webserver_request)
+bool editor_style_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = access_bible::any (webserver_request);
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
+  const auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string editor_style (void * webserver_request)
+std::string editor_style (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  
-  if (request->query.count ("style")) {
-    string style = request->query["style"];
-    Editor_Styles::recordUsage (request, style);
-    string action = Editor_Styles::getAction (request, style);
+  if (webserver_request.query.count ("style")) {
+    const std::string style = webserver_request.query["style"];
+    Editor_Styles::recordUsage (webserver_request, style);
+    const std::string action = Editor_Styles::getAction (webserver_request, style);
     return style + "\n" + action;
   }
   
-  
-  if (request->query.count ("all")) {
-    return Editor_Styles::getAll (request);
+  if (webserver_request.query.count ("all")) {
+    return Editor_Styles::getAll (webserver_request);
   }
   
-  
-  return Editor_Styles::getRecentlyUsed (request);
+  return Editor_Styles::getRecentlyUsed (webserver_request);
 }
 
