@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -26,16 +26,17 @@
 #include <access/bible.h>
 
 
-string editusfm_focus_url ()
+std::string editusfm_focus_url ()
 {
   return "editusfm/focus";
 }
 
 
-bool editusfm_focus_acl (void * webserver_request)
+bool editusfm_focus_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
@@ -43,14 +44,13 @@ bool editusfm_focus_acl (void * webserver_request)
 // Returns two numerical positions: A starting one, and an ending one.
 // These two are for positioning the caret in the editor.
 // The caret should be at or be moved to a position between these two.
-string editusfm_focus (void * webserver_request)
+std::string editusfm_focus (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  string bible = request->query ["bible"];
-  int book = convert_to_int (request->query ["book"]);
-  int chapter = convert_to_int (request->query ["chapter"]);
-  string usfm = request->database_bibles()->getChapter (bible, book, chapter);
-  int verse = Ipc_Focus::getVerse (request);
+  std::string bible = webserver_request.query ["bible"];
+  int book = filter::strings::convert_to_int (webserver_request.query ["book"]);
+  int chapter = filter::strings::convert_to_int (webserver_request.query ["chapter"]);
+  std::string usfm = database::bibles::get_chapter (bible, book, chapter);
+  int verse = Ipc_Focus::getVerse (webserver_request);
   int startingOffset = filter::usfm::versenumber_to_offset (usfm, verse);
   int endingOffset = startingOffset;
   // The following deals with a combined verse.
@@ -60,7 +60,7 @@ string editusfm_focus (void * webserver_request)
       if (endingOffset > startingOffset) endingOffset--;
     }
   }
-  string data = convert_to_string (startingOffset) + " " + convert_to_string (endingOffset);
+  std::string data = std::to_string (startingOffset) + " " + std::to_string (endingOffset);
   return data;
 }
 
