@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_EMAIL_INDEX_H
-#define INCLUDED_EMAIL_INDEX_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string email_index_url ();
-bool email_index_acl (void * webserver_request);
-string email_index (void * webserver_request);
-
-
-#endif
+std::string email_index_url ();
+bool email_index_acl (Webserver_Request& webserver_request);
+std::string email_index (Webserver_Request& webserver_request);
