@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,5 +22,5 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <config/libraries.h>
 
 void email_receive ();
-int email_receive_count (string& error, bool verbose = false);
-string email_receive_message (string& error);
+int email_receive_count (std::string& error, bool verbose = false);
+std::string email_receive_message (std::string& error);
