@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -37,27 +37,23 @@
 #include <html/header.h>
 #include <locale/translate.h>
 #include <styles/sheets.h>
-using namespace std;
 
 
-void export_html_book (string bible, int book, bool log)
+void export_html_book (const std::string& bible, const int book, const bool log)
 {
   // Create folders for the html export.
-  string directory = filter_url_create_path ({export_logic::bible_directory (bible), "html"});
-  if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
+  const std::string directory = filter_url_create_path ({export_logic::bible_directory (bible), "html"});
+  if (!file_or_dir_exists (directory))
+    filter_url_mkdir (directory);
   
   
   // Filename for the html file.
-  string basename = export_logic::base_book_filename (bible, book);
-  string filename_html = filter_url_create_path ({directory, basename + ".html"});
-  string stylesheet_css = filter_url_create_path ({directory, "stylesheet.css"});
+  const std::string basename = export_logic::base_book_filename (bible, book);
+  const std::string filename_html = filter_url_create_path ({directory, basename + ".html"});
+  const std::string stylesheet_css = filter_url_create_path ({directory, "stylesheet.css"});
   
   
-  Database_Bibles database_bibles;
-  Database_BibleImages database_bibleimages;
-
-  
-  string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
+  const std::string stylesheet = database::config::bible::get_export_stylesheet (bible);
   
   
   // Create stylesheet.
@@ -66,11 +62,11 @@ void export_html_book (string bible, int book, bool log)
   
   
   // Copy font to the output directory.
-  string font = fonts::logic::get_text_font (bible);
+  const std::string font = fonts::logic::get_text_font (bible);
   if (!font.empty ()) {
     if (fonts::logic::font_exists (font)) {
-      string fontpath = fonts::logic::get_font_path (font);
-      string contents = filter_url_file_get_contents (fontpath);
+      std::string fontpath = fonts::logic::get_font_path (font);
+      const std::string contents = filter_url_file_get_contents (fontpath);
       fontpath = filter_url_create_path ({directory, font});
       filter_url_file_put_contents (fontpath, contents);
     }
@@ -80,16 +76,16 @@ void export_html_book (string bible, int book, bool log)
   Filter_Text filter_text = Filter_Text (bible);
   filter_text.html_text_standard = new HtmlText (translate("Bible"));
   filter_text.html_text_standard->custom_class = Filter_Css::getClass (bible);
-  if (Database_Config_Bible::getExportHtmlNotesOnHover(bible)) {
+  if (database::config::bible::get_export_html_notes_on_hover(bible)) {
     filter_text.html_text_standard->have_popup_notes();
   }
   
   
   // Load one book.
-  vector <int> chapters = database_bibles.getChapters (bible, book);
-  for (auto chapter : chapters) {
+  const std::vector <int> chapters = database::bibles::get_chapters (bible, book);
+  for (const auto chapter : chapters) {
     // Get the USFM for this chapter.
-    string usfm = database_bibles.getChapter (bible, book, chapter);
+    std::string usfm = database::bibles::get_chapter (bible, book, chapter);
     usfm = filter::strings::trim (usfm);
     // Use small chunks of USFM at a time for much better performance.
     filter_text.add_usfm_code (usfm);
@@ -105,9 +101,9 @@ void export_html_book (string bible, int book, bool log)
   
   
   // Save any images that were included.
-  for (auto src : filter_text.image_sources) {
-    string contents = database_bibleimages.get(src);
-    string filename = filter_url_create_path ({directory, src});
+  for (const auto src : filter_text.image_sources) {
+    const std::string contents = database::bible_images::get(src);
+    const std::string filename = filter_url_create_path ({directory, src});
     filter_url_file_put_contents(filename, contents);
   }
 
@@ -116,5 +112,6 @@ void export_html_book (string bible, int book, bool log)
   Database_State::clearExport (bible, book, export_logic::export_html);
 
   
-  if (log) Database_Logs::log (translate("Exported to html") + ": " + bible + " " + database::books::get_english_from_id (static_cast<book_id>(book)), Filter_Roles::translator ());
+  if (log) 
+    Database_Logs::log (translate("Exported to html") + ": " + bible + " " + database::books::get_english_from_id (static_cast<book_id>(book)), Filter_Roles::translator ());
 }
