@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -33,31 +33,27 @@
 #include <filter/archive.h>
 #include <filter/shell.h>
 #include <filter/usfm.h>
+#include <filter/passage.h>
 #include <locale/translate.h>
 #include <styles/sheets.h>
-using namespace std;
 
 
-void export_odt_book (string bible, int book, bool log)
+void export_odt_book (std::string bible, int book, bool log)
 {
   // Create folders for the OpenDocument export.
-  string directory = filter_url_create_path ({export_logic::bible_directory (bible), "opendocument"});
+  std::string directory = filter_url_create_path ({export_logic::bible_directory (bible), "opendocument"});
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
   // Filenames for the various types of OpenDocument files.
-  string basename = export_logic::base_book_filename (bible, book);
-  string standardFilename = filter_url_create_path ({directory, basename + "_standard.odt"});
-  string textOnlyFilename = filter_url_create_path ({directory, basename + "_text_only.odt"});
-  string textAndCitationsFilename = filter_url_create_path ({directory, basename + "_text_and_note_citations.odt"});
-  string notesFilename = filter_url_create_path ({directory, basename + "_notes.odt"});
+  std::string basename = export_logic::base_book_filename (bible, book);
+  std::string standardFilename = filter_url_create_path ({directory, basename + "_standard.odt"});
+  std::string textOnlyFilename = filter_url_create_path ({directory, basename + "_text_only.odt"});
+  std::string textAndCitationsFilename = filter_url_create_path ({directory, basename + "_text_and_note_citations.odt"});
+  std::string notesFilename = filter_url_create_path ({directory, basename + "_notes.odt"});
 
   
-  Database_Bibles database_bibles;
-  Database_BibleImages database_bibleimages;
-  
-  
-  string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
+  const std::string stylesheet = database::config::bible::get_export_stylesheet (bible);
   
   
   Filter_Text filter_text = Filter_Text (bible);
@@ -69,11 +65,11 @@ void export_odt_book (string bible, int book, bool log)
   
   if (book == 0) {
     // Load entire Bible, ordered.
-    vector <int> books = filter_passage_get_ordered_books (bible);
+    std::vector <int> books = filter_passage_get_ordered_books (bible);
     for (auto book2 : books) {
-      vector <int> chapters = database_bibles.getChapters (bible, book2);
+      std::vector <int> chapters = database::bibles::get_chapters (bible, book2);
       for (auto chapter : chapters) {
-        string usfm = database_bibles.getChapter (bible, book2, chapter);
+        std::string usfm = database::bibles::get_chapter (bible, book2, chapter);
         usfm = filter::strings::trim (usfm);
         // Use small chunks of USFM at a time for much better performance.
         filter_text.add_usfm_code (usfm);
@@ -81,9 +77,9 @@ void export_odt_book (string bible, int book, bool log)
     }
   } else {
     // Load one book.
-    vector <int> chapters = database_bibles.getChapters (bible, book);
+    std::vector <int> chapters = database::bibles::get_chapters (bible, book);
     for (auto chapter : chapters) {
-      string usfm = database_bibles.getChapter (bible, book, chapter);
+      std::string usfm = database::bibles::get_chapter (bible, book, chapter);
       usfm = filter::strings::trim (usfm);
       // Use small chunks of USFM at a time for much better performance.
       filter_text.add_usfm_code (usfm);
@@ -101,17 +97,17 @@ void export_odt_book (string bible, int book, bool log)
   filter_text.odf_text_text_and_note_citations->save (textAndCitationsFilename);
   filter_text.odf_text_notes->save (notesFilename);
   for (auto src : filter_text.image_sources) {
-    string contents = database_bibleimages.get(src);
-    string path = filter_url_create_path ({directory, src});
+    std::string contents = database::bible_images::get(src);
+    std::string path = filter_url_create_path ({directory, src});
     filter_url_file_put_contents(path, contents);
   }
 
     
   // Securing the OpenDocument export implies that the exported files are zipped and secured with a password.
   // It uses the external zip binary.
-  bool secure = Database_Config_Bible::getSecureOdtExport (bible);
-  string password = Database_Config_Bible::getExportPassword (bible);
-  string basefile = filter_url_basename (standardFilename);
+  bool secure = database::config::bible::get_secure_odt_export (bible);
+  std::string password = database::config::bible::get_export_password (bible);
+  std::string basefile = filter_url_basename (standardFilename);
   filter_url_unlink (standardFilename + ".zip");
   if (secure) {
     filter_shell_run (directory, "zip", {"-P", password, basefile + ".zip", basefile}, nullptr, nullptr);
@@ -142,7 +138,7 @@ void export_odt_book (string bible, int book, bool log)
 
   
   if (log) {
-    string bookname;
+    std::string bookname;
     if (book) bookname = database::books::get_english_from_id (static_cast<book_id>(book));
     else bookname = translate ("whole Bible");
     Database_Logs::log (translate("Exported to OpenDocument files") + " " + bible + " " + bookname, Filter_Roles::translator ());
