@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -52,24 +52,24 @@ int filter_memory_percentage_available ()
   // http://stackoverflow.com/questions/2513505/how-to-get-available-memory-c-g
   
   // Linux.
-  string path = "/proc/meminfo";
+  std::string path = "/proc/meminfo";
   if (file_or_dir_exists (path)) {
-    string meminfo = filter_url_file_get_contents (path);
+    std::string meminfo = filter_url_file_get_contents (path);
     size_t pos;
     int memtotal = 0;
     pos = meminfo.find ("MemTotal");
-    if (pos != string::npos) {
-      memtotal = convert_to_int (meminfo.substr (pos + 15));
+    if (pos != std::string::npos) {
+      memtotal = filter::strings::convert_to_int (meminfo.substr (pos + 15));
     }
     int memfree = 0;
     pos = meminfo.find ("MemFree");
-    if (pos != string::npos) {
-      memfree = convert_to_int (meminfo.substr (pos + 15));
+    if (pos != std::string::npos) {
+      memfree = filter::strings::convert_to_int (meminfo.substr (pos + 15));
     }
     int cached = 0;
     pos = meminfo.find ("Cached");
-    if (pos != string::npos) {
-      cached = convert_to_int (meminfo.substr (pos + 15));
+    if (pos != std::string::npos) {
+      cached = filter::strings::convert_to_int (meminfo.substr (pos + 15));
     }
     return (memfree + cached) * 100 / memtotal;
   }
@@ -81,7 +81,7 @@ int filter_memory_percentage_available ()
 
 
 // Returns how many bytes of memory the app currently uses.
-uint64_t filter_memory_total_usage ()
+uint64_t filter_memory_total_usage () 
 {
 #ifdef HAVE_MACH_MACH
   // macOS.
@@ -108,7 +108,7 @@ void filter_memory_print_back_trace ()
   int size = backtrace(array, 1024);
   strings = backtrace_symbols(array, size);
   for (int i = 0; i < size; i++)
-    cout << strings[i] << endl;
+    std::cout << strings[i] << std::endl;
   puts("");
   free(strings);
 #endif
