@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <filter/roles.h>
 #include <locale/translate.h>
-using namespace std;
+#include <webserver/request.h>
 
 
 int Filter_Roles::guest ()
@@ -70,7 +70,7 @@ int Filter_Roles::highest ()
 }
 
 
-string Filter_Roles::english (int role)
+std::string Filter_Roles::english (int role)
 {
   if (role == admin ()) return "Administrator";
   if (role == manager ()) return "Manager";
@@ -81,23 +81,26 @@ string Filter_Roles::english (int role)
 }
 
 
-string Filter_Roles::text (int role)
+std::string Filter_Roles::text (int role)
 {
-  if (role == admin ()) return translate ("Administrator");
-  if (role == manager ()) return translate ("Manager");
-  if (role == translator ()) return translate ("Translator");
-  if (role == consultant ())return translate ("Consultant");
-  if (role == member ()) return translate ("Member");
+  if (role == admin ()) 
+    return translate ("Administrator");
+  if (role == manager ()) 
+    return translate ("Manager");
+  if (role == translator ()) 
+    return translate ("Translator");
+  if (role == consultant ())
+    return translate ("Consultant");
+  if (role == member ()) 
+    return translate ("Member");
   return translate ("Guest");
 }
 
 
 // This is for access control.
 // The "role" is the role required for the user to have access.
-bool Filter_Roles::access_control (void * webserver_request, int role)
+bool Filter_Roles::access_control (Webserver_Request& webserver_request, int role)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  int level = request->session_logic ()->currentLevel ();
+  int level = webserver_request.session_logic ()->get_level ();
   return level >= role;
 }
-
