@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,10 +19,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <filter/webview.h>
 #include <database/logs.h>
-using namespace std;
 
 
-void filter_webview_log_user_agent (string user_agent)
+void filter_webview_log_user_agent (std::string user_agent)
 {
   // Whether the information has been logged.
   static bool filter_webview_logged = false;
