@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_LEXICON_DEFINITION_H
-#define INCLUDED_LEXICON_DEFINITION_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string lexicon_definition_url ();
-bool lexicon_definition_acl (void * webserver_request);
-string lexicon_definition (void * webserver_request);
-
-
-#endif
+std::string lexicon_definition_url ();
+bool lexicon_definition_acl (Webserver_Request& webserver_request);
+std::string lexicon_definition (Webserver_Request& webserver_request);
