@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -41,29 +41,26 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <menu/logic.h>
 #include <session/switch.h>
 #include <user/logic.h>
-using namespace std;
 
 
-string manage_accounts_url ()
+std::string manage_accounts_url ()
 {
   return "manage/accounts";
 }
 
 
-bool manage_accounts_acl (void * webserver_request)
+bool manage_accounts_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
 }
 
 
-string manage_accounts (void * webserver_request)
+std::string manage_accounts (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
   bool user_updated = false;
   bool privileges_updated = false;
   
-  string page;
+  std::string page;
   Assets_Header header = Assets_Header (translate("Accounts"), webserver_request);
   header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
@@ -71,24 +68,23 @@ string manage_accounts (void * webserver_request)
   Assets_View view;
 
   // The user to act on.
-  string objectUsername = request->query["user"];
-  int user_level = request->database_users ()->get_level (objectUsername);
+  std::string objectUsername = webserver_request.query["user"];
+  int user_level = webserver_request.database_users ()->get_level (objectUsername);
   
   // Delete a user.
-  if (request->query.count ("delete")) {
-    string role = Filter_Roles::text (user_level);
-    string email = request->database_users ()->get_email (objectUsername);
-    vector <string> users = request->database_users ()->get_users ();
-    vector <string> administrators = request->database_users ()->getAdministrators ();
+  if (webserver_request.query.count ("delete")) {
+    std::string role = Filter_Roles::text (user_level);
+    std::string email = webserver_request.database_users ()->get_email (objectUsername);
+    std::vector <std::string> users = webserver_request.database_users ()->get_users ();
+    std::vector <std::string> administrators = webserver_request.database_users ()->getAdministrators ();
     if (users.size () == 1) {
       page += assets_page::error (translate("Cannot remove the last user"));
     } else if ((user_level >= Filter_Roles::admin ()) && (administrators.size () == 1)) {
       page += assets_page::error (translate("Cannot remove the last administrator"));
     } else {
-      string message;
+      std::string message;
       user_logic_delete_account (objectUsername, role, email, message);
       user_updated = true;
-      tasks_logic_queue (DELETEINDONESIANFREEUSER, {objectUsername, email});
       message.append (" ");
       message.append ("See the Journal for progress");
       page += assets_page::success (message);
@@ -96,43 +92,35 @@ string manage_accounts (void * webserver_request)
   }
   
   // Get the account creation times.
-  map <string, int> account_creation_times;
+  std::map <std::string, int> account_creation_times;
   {
-    vector <string> lines = Database_Config_General::getAccountCreationTimes ();
+    std::vector <std::string> lines = database::config::general::get_account_creation_times ();
     for (auto line : lines) {
-      vector <string> bits = filter_string_explode(line, '|');
+      std::vector <std::string> bits = filter::strings::explode(line, '|');
       if (bits.size() != 2) continue;
-      int seconds = convert_to_int(bits[0]);
-      string user = bits[1];
+      int seconds = filter::strings::convert_to_int(bits[0]);
+      std::string user = bits[1];
       account_creation_times [user] = seconds;
     }
   }
   
   // Retrieve assigned users.
-  vector <string> users = access_user::assignees (webserver_request);
-  for (auto & username : users) {
+  const std::vector <std::string> users = access_user::assignees (webserver_request);
+  for (const auto& username : users) {
     
     // Gather details for this user account.
-    user_level = request->database_users ()->get_level (username);
-    string role = Filter_Roles::text (user_level);
-    string email = request->database_users ()->get_email (username);
-    int seconds = filter::date::seconds_since_epoch() - account_creation_times[username];
-    string days = convert_to_string (seconds / (3600 * 24));
+    user_level = webserver_request.database_users ()->get_level (username);
+    const std::string role = Filter_Roles::text (user_level);
+    const std::string email = webserver_request.database_users ()->get_email (username);
+    const int seconds = filter::date::seconds_since_epoch() - account_creation_times[username];
+    const std::string days = std::to_string (seconds / (3600 * 24));
     
-    // In the Indonesian free Cloud,
-    // the free guest accounts have a role of Consultant.
-    // So only displays roles of Consultant or lower.
-    // Skip any higher roles.
-    if (config::logic::indonesian_cloud_free ()) {
-      if (user_level > Filter_Roles::consultant()) continue;
-    }
-
     // Pass information about this user to the flate engine for display.
     view.add_iteration ("tbody", {
-      pair ("user", username),
-      pair ("days", days),
-      pair ("role", role),
-      pair ("email", email),
+      std::pair ("user", username),
+      std::pair ("days", days),
+      std::pair ("role", role),
+      std::pair ("email", email),
     });
   }
   
