@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,23 +24,22 @@
 #include <menu/logic.h>
 
 
-string menu_index_url ()
+std::string menu_index_url ()
 {
   return "menu/index";
 }
 
 
-bool menu_index_acl (void * webserver_request)
+bool menu_index_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::guest ());
 }
 
 
-string menu_index (void * webserver_request)
+std::string menu_index (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
-  string item = request->query ["item"];
+  std::string item = webserver_request.query ["item"];
   item = menu_logic_click (item);
-  redirect_browser (request, item);
-  return "";
+  redirect_browser (webserver_request, item);
+  return std::string();
 }
