@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -35,57 +35,54 @@
 #include <notes/index.h>
 #include <dialog/yes.h>
 #include <trash/handler.h>
-using namespace std;
 
 
-string notes_click_url ()
+std::string notes_click_url ()
 {
   return "notes/click";
 }
 
 
-bool notes_click_acl (void * webserver_request)
+bool notes_click_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
 }
 
 
 // This function is called from click.js.
-string notes_click (void * webserver_request)
+std::string notes_click (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
-  Notes_Logic notes_logic = Notes_Logic (webserver_request);
+  Notes_Logic notes_logic (webserver_request);
   
   
-  if (request->query.count ("open")) {
-    string open = request->query ["open"];
+  if (webserver_request.query.count ("open")) {
+    std::string open = webserver_request.query ["open"];
     open = filter_url_basename_web (open);
     int iopen = filter::strings::convert_to_int (open);
     if (database_notes.identifier_exists (iopen)) {
-      Ipc_Notes::open (request, iopen);
+      Ipc_Notes::open (webserver_request, iopen);
     }
   }
   
   
-  if (request->query.count ("new")) {
-    string snew = request->query ["new"];
+  if (webserver_request.query.count ("new")) {
+    std::string snew = webserver_request.query ["new"];
     snew = filter_url_basename_web (snew);
     int inew = filter::strings::convert_to_int (snew);
-    Database_Modifications database_modifications;
-    string bible = database_modifications.getNotificationBible (inew);
-    string summary = translate("Query about a change in the text");
-    string contents = "<p>" + translate("Old text:") + "</p>";
-    contents += database_modifications.getNotificationOldText (inew);
+    std::string bible = database::modifications::getNotificationBible (inew);
+    std::string summary = translate("Query about a change in the text");
+    std::string contents = "<p>" + translate("Old text:") + "</p>";
+    contents += database::modifications::getNotificationOldText (inew);
     contents += "<p>" +  translate("Change:") + "</p>";
-    contents += "<p>" + database_modifications.getNotificationModification (inew) + "</p>";
+    contents += "<p>" + database::modifications::getNotificationModification (inew) + "</p>";
     contents += "<p>" + translate("New text:") + "</p>";
-    contents += database_modifications.getNotificationNewText (inew);
-    Passage passage = database_modifications.getNotificationPassage (inew);
+    contents += database::modifications::getNotificationNewText (inew);
+    Passage passage = database::modifications::getNotificationPassage (inew);
     int identifier = notes_logic.createNote (bible, passage.m_book, passage.m_chapter, filter::strings::convert_to_int (passage.m_verse), summary, contents, false);
-    Ipc_Notes::open (request, identifier);
+    Ipc_Notes::open (webserver_request, identifier);
   }
   
 
-  return "";
+  return std::string();
 }
