@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -36,51 +36,50 @@
 #include <access/logic.h>
 
 
-string notes_note_url ()
+std::string notes_note_url ()
 {
   return "notes/note";
 }
 
 
-bool notes_note_acl (void * webserver_request)
+bool notes_note_acl (Webserver_Request& webserver_request)
 {
-  return access_logic_privilege_view_notes (webserver_request);
+  return access_logic::privilege_view_notes (webserver_request);
 }
 
 
-string notes_note (void * webserver_request)
+std::string notes_note (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   
   
-  string page;
-  Assets_Header header = Assets_Header (translate("Note"), request);
-  header.setNavigator ();
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Note"), webserver_request);
+  header.set_navigator ();
 
   
   // After adding a comment to a note, when doing nothing for several seconds,
   // the browser then returns to the list of notes.
-  if (request->query.count ("temporal")) {
+  if (webserver_request.query.count ("temporal")) {
     header.refresh (5, "index");
   }
 
   
   page += header.run ();
   Assets_View view;
-  string success;
+  std::string success;
 
   
-  int id = convert_to_int (request->query ["id"]);
+  int id = filter::strings::convert_to_int (webserver_request.query ["id"]);
   
   
   // When a note is opened, then the passage navigator should go to the passage that belongs to that note.
-  vector <Passage> passages = database_notes.get_passages (id);
+  std::vector <Passage> passages = database_notes.get_passages (id);
   if (!passages.empty ()) {
     Passage focused_passage;
     focused_passage.m_book = Ipc_Focus::getBook (webserver_request);
     focused_passage.m_chapter = Ipc_Focus::getChapter (webserver_request);
-    focused_passage.m_verse = convert_to_string (Ipc_Focus::getVerse (webserver_request));
+    focused_passage.m_verse = std::to_string (Ipc_Focus::getVerse (webserver_request));
     // Only set passage and track history if the focused passage
     // differs from all of the passages of the note.
     // If the focused passage is already at any of the passages belonging to the note,
@@ -92,36 +91,36 @@ string notes_note (void * webserver_request)
     if (!passage_focused) {
       int desired_book = passages[0].m_book;
       int desired_chapter = passages[0].m_chapter;
-      int desired_verse = convert_to_int (passages[0].m_verse);
+      int desired_verse = filter::strings::convert_to_int (passages[0].m_verse);
       Ipc_Focus::set (webserver_request, desired_book, desired_chapter, desired_verse);
       Navigation_Passage::record_history (webserver_request, desired_book, desired_chapter, desired_verse);
     }
   }
   
   
-  view.set_variable ("id", convert_to_string (id));
+  view.set_variable ("id", std::to_string (id));
 
 
   view.set_variable ("passage", filter_passage_display_inline (passages));
   
 
-  string summary = database_notes.get_summary (id);
+  std::string summary = database_notes.get_summary (id);
   view.set_variable ("summary", summary);
 
   
-  bool show_note_status = request->database_config_user ()->getShowNoteStatus ();
+  bool show_note_status = webserver_request.database_config_user ()->getShowNoteStatus ();
   if (show_note_status) {
-    string status = database_notes.get_status (id);
+    std::string status = database_notes.get_status (id);
     view.set_variable ("status", status);
   }
   
   
-  if (request->session_logic ()->currentLevel () >= Filter_Roles::translator ()) {
+  if (webserver_request.session_logic ()->get_level () >= Filter_Roles::translator ()) {
     view.enable_zone ("editlevel");
   }
   
   
-  string content = database_notes.get_contents (id);
+  std::string content = database_notes.get_contents (id);
   view.set_variable ("content", content);
 
   
@@ -132,7 +131,7 @@ string notes_note (void * webserver_request)
   view.set_variable ("brs", filter_html_android_brs ());
   
 
-  if (request->database_config_user ()->getQuickNoteEditLink ()) {
+  if (webserver_request.database_config_user ()->getQuickNoteEditLink ()) {
     view.enable_zone ("editcontent");
   }
     
@@ -140,12 +139,12 @@ string notes_note (void * webserver_request)
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) {
     view.enable_zone ("consultant");
   }
-  if (access_logic_privilege_create_comment_notes (webserver_request)) {
+  if (access_logic::privilege_create_comment_notes (webserver_request)) {
     view.enable_zone ("comment");
   }
   
   view.set_variable ("success", success);
   page += view.render ("notes", "note");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
