@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_NOTES_STATUS_N_H
-#define INCLUDED_NOTES_STATUS_N_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string notes_status_n_url ();
-bool notes_status_n_acl (void * webserver_request);
-string notes_status_n (void * webserver_request);
-
-
-#endif
+std::string notes_status_n_url ();
+bool notes_status_n_acl (Webserver_Request& webserver_request);
+std::string notes_status_n (Webserver_Request& webserver_request);
