@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,42 +34,41 @@
 #include <notes/actions.h>
 
 
-string notes_verses_url ()
+std::string notes_verses_url ()
 {
   return "notes/verses";
 }
 
 
-bool notes_verses_acl (void * webserver_request)
+bool notes_verses_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
 }
 
 
-string notes_verses (void * webserver_request)
+std::string notes_verses (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
-  Notes_Logic notes_logic = Notes_Logic (webserver_request);
+  Notes_Logic notes_logic (webserver_request);
 
 
-  string page;
-  Assets_Header header = Assets_Header (translate("Passages"), request);
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Passages"), webserver_request);
   page += header.run ();
   Assets_View view;
-  string success, error;
+  std::string success, error;
   
   
-  int id = convert_to_int (request->query ["id"]);
-  view.set_variable ("id", convert_to_string (id));
+  int id = filter::strings::convert_to_int (webserver_request.query ["id"]);
+  view.set_variable ("id", std::to_string (id));
 
 
-  if (request->post.count ("submit")) {
-    vector <string> verses = filter_string_explode (request->post["verses"], '\n');
-    vector <Passage> passages;
+  if (webserver_request.post.count ("submit")) {
+    std::vector <std::string> verses = filter::strings::explode (webserver_request.post["verses"], '\n');
+    std::vector <Passage> passages;
     Passage previousPassage = Passage ("", 1, 1, "1");
     for (auto & line : verses) {
-      line = filter_string_trim (line);
+      line = filter::strings::trim (line);
       if (line != "") {
         Passage passage = filter_passage_interpret_passage (previousPassage, line);
         if (passage.m_book != 0) {
@@ -82,19 +81,19 @@ string notes_verses (void * webserver_request)
       error = translate ("The note should have one or more passages assigned.");
     } else {
       notes_logic.setPassages (id, passages);
-      redirect_browser (request, notes_actions_url () + "?id=" + convert_to_string (id));
-      return "";
+      redirect_browser (webserver_request, notes_actions_url () + "?id=" + std::to_string (id));
+      return std::string();
     }
   }
   
   
-  string verses = filter_passage_display_multiline (database_notes.get_passages (id));
+  std::string verses = filter_passage_display_multiline (database_notes.get_passages (id));
   view.set_variable ("verses", verses);
   
   
   view.set_variable ("success", success);
   view.set_variable ("error", error);
   page += view.render ("notes", "verses");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
