@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,4 +21,6 @@
 
 #include <config/libraries.h>
 
-std::vector <std::string> public_logic_bibles (void * webserver_request);
+class Webserver_Request;
+
+std::vector <std::string> public_logic_bibles (Webserver_Request& webserver_request);
