@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -29,57 +29,57 @@
 #include <database/notes.h>
 #include <public/index.h>
 #include <read/index.h>
-using namespace std;
+#include <config/logic.h>
 
 
-string public_note_url ()
+std::string public_note_url ()
 {
   return "public/note";
 }
 
 
-bool public_note_acl (void * webserver_request)
+bool public_note_acl (Webserver_Request& webserver_request)
 {
+  if (config::logic::create_no_accounts()) return false;
   return Filter_Roles::access_control (webserver_request, Filter_Roles::guest ());
 }
 
 
-string public_note (void * webserver_request)
+std::string public_note (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   
   
-  string page;
-  Assets_Header header = Assets_Header (translate("Note"), request);
+  std::string page {};
+  Assets_Header header = Assets_Header (translate("Note"), webserver_request);
 
   
   // After adding a comment to a note, when doing nothing for several seconds,
   // the browser then returns to the list of public notes.
-  if (request->query.count ("temporal")) {
+  if (webserver_request.query.count ("temporal")) {
     header.refresh (5, "index");
   }
 
   
   page += header.run ();
   Assets_View view;
-  string success;
+  std::string success;
 
   
-  int id = filter::strings::convert_to_int (request->query ["id"]);
-  view.set_variable ("id", filter::strings::convert_to_string (id));
+  const int id = filter::strings::convert_to_int (webserver_request.query ["id"]);
+  view.set_variable ("id", std::to_string (id));
   
   
   if (database_notes.get_public (id)) {
-    string summary = database_notes.get_summary (id);
+    const std::string summary = database_notes.get_summary (id);
     view.set_variable ("summary", summary);
 
-    string content = database_notes.get_contents (id);
+    const std::string content = database_notes.get_contents (id);
     view.set_variable ("content", content);
   }
 
 
-  string url_to_index = "index";
+  const std::string url_to_index = "index";
   view.set_variable ("url_to_index", url_to_index);
 
   
