@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -93,7 +93,7 @@ Stages to retrieve resource content and serve it.
 */
 
 
-std::vector <std::string> resource_logic_get_names (void * webserver_request, bool bibles_only)
+std::vector <std::string> resource_logic_get_names (Webserver_Request& webserver_request, bool bibles_only)
 {
   std::vector <std::string> names {};
   
@@ -137,12 +137,10 @@ std::vector <std::string> resource_logic_get_names (void * webserver_request, bo
 }
 
 
-std::string resource_logic_get_html (void * webserver_request,
+std::string resource_logic_get_html (Webserver_Request& webserver_request,
                                      std::string resource, int book, int chapter, int verse,
                                      bool add_verse_numbers)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
   // Determine the type of the resource.
   bool is_bible = resource_logic_is_bible (resource);
   bool is_usfm = resource_logic_is_usfm (resource);
@@ -184,13 +182,13 @@ std::string resource_logic_get_html (void * webserver_request,
   Database_Mappings database_mappings;
 
   // Retrieve versification system of the active Bible.
-  std::string bible = request->database_config_user ()->getBible ();
-  std::string bible_versification = Database_Config_Bible::getVersificationSystem (bible);
+  std::string bible = webserver_request.database_config_user ()->getBible ();
+  std::string bible_versification = database::config::bible::get_versification_system (bible);
 
   // Determine the versification system of the current resource.
   std::string resource_versification;
   if (is_bible || is_usfm) {
-    resource_versification = Database_Config_Bible::getVersificationSystem (bible);
+    resource_versification = database::config::bible::get_versification_system (bible);
   } else if (is_external) {
     resource_versification = resource_external_mapping (resource);
   } else if (is_image) {
@@ -213,7 +211,7 @@ std::string resource_logic_get_html (void * webserver_request,
   if ((bible_versification != resource_versification) && !resource_versification.empty ()) {
     passages = database_mappings.translate (bible_versification, resource_versification, book, chapter, verse);
   } else {
-    passages.push_back (Passage ("", book, chapter, filter::strings::convert_to_string (verse)));
+    passages.push_back (Passage ("", book, chapter, std::to_string (verse)));
   }
 
   // If there's been a mapping, the resource should include the verse number for clarity.
@@ -228,7 +226,7 @@ std::string resource_logic_get_html (void * webserver_request,
   bool add_passages_in_full = false;
 
   // Deal with user's preference whether to include related passages.
-  if (request->database_config_user ()->getIncludeRelatedPassages ()) {
+  if (webserver_request.database_config_user ()->getIncludeRelatedPassages ()) {
     
     // Take the Bible's active passage and mapping, and translate that to the original mapping.
     std::vector <Passage> related_passages = database_mappings.translate (bible_versification, database_mappings.original (), book, chapter, verse);
@@ -270,10 +268,8 @@ std::string resource_logic_get_html (void * webserver_request,
 // This is the most basic version that fetches the text of a $resource.
 // It works on server and on client.
 // It uses the cache.
-std::string resource_logic_get_verse (void * webserver_request, std::string resource, int book, int chapter, int verse)
+std::string resource_logic_get_verse (Webserver_Request& webserver_request, std::string resource, int book, int chapter, int verse)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
   std::string data {};
 
   // Determine the type of the current resource.
@@ -295,7 +291,8 @@ std::string resource_logic_get_verse (void * webserver_request, std::string reso
   
   if (isBible || isLocalUsfm) {
     std::string chapter_usfm {};
-    if (isBible) chapter_usfm = request->database_bibles()->getChapter (resource, book, chapter);
+    if (isBible) 
+      chapter_usfm = database::bibles::get_chapter (resource, book, chapter);
     if (isLocalUsfm) chapter_usfm = database_usfmresources.getUsfm (resource, book, chapter);
     std::string verse_usfm = filter::usfm::get_verse_text (chapter_usfm, verse);
     std::string stylesheet = styles_logic_standard_sheet ();
@@ -321,7 +318,7 @@ std::string resource_logic_get_verse (void * webserver_request, std::string reso
       data.append ("<div><img src=\"/resource/imagefetch?name=" + resource + "&image=" + image + "\" alt=\"Image resource\" style=\"width:100%\"></div>");
     }
   } else if (isLexicon) {
-    data = lexicon_logic_get_html (request, resource, book, chapter, verse);
+    data = lexicon_logic_get_html (webserver_request, resource, book, chapter, verse);
   } else if (isSword) {
     const std::string sword_module = sword_logic_get_remote_module (resource);
     const std::string sword_source = sword_logic_get_source (resource);
@@ -354,7 +351,7 @@ std::string resource_logic_get_verse (void * webserver_request, std::string reso
 }
 
 
-std::string resource_logic_cloud_get_comparison (void * webserver_request,
+std::string resource_logic_cloud_get_comparison (Webserver_Request& webserver_request,
                                                  std::string resource, int book, int chapter, int verse,
                                                  bool add_verse_numbers)
 {
@@ -363,7 +360,7 @@ std::string resource_logic_cloud_get_comparison (void * webserver_request,
   // And then get the additional properties belonging to this resource.
   std::string title, base, update, remove, replace;
   bool diacritics = false, casefold = false;
-  std::vector <std::string> resources = Database_Config_General::getComparativeResources ();
+  std::vector <std::string> resources = database::config::general::get_comparative_resources ();
   for (const auto& s : resources) {
     resource_logic_parse_comparative_resource (s, &title, &base, &update, &remove, &replace, &diacritics, &casefold);
     if (title == resource) break;
@@ -427,7 +424,7 @@ std::string resource_logic_cloud_get_comparison (void * webserver_request,
 }
 
 
-std::string resource_logic_cloud_get_translation (void * webserver_request,
+std::string resource_logic_cloud_get_translation (Webserver_Request& webserver_request,
                                                   const std::string& resource,
                                                   int book, int chapter, int verse,
                                                   bool add_verse_numbers)
@@ -436,7 +433,7 @@ std::string resource_logic_cloud_get_translation (void * webserver_request,
   // So get all defined translated resources and look for the one with this title.
   // And then get the additional properties belonging to this resource.
   std::string title, original_resource, source_language, target_language;
-  std::vector <std::string> resources = Database_Config_General::getTranslatedResources ();
+  std::vector <std::string> resources = database::config::general::get_translated_resources ();
   for (const auto& input : resources) {
     resource_logic_parse_translated_resource (input, &title, &original_resource, &source_language, &target_language);
     if (title == resource) break;
@@ -513,15 +510,15 @@ std::string resource_logic_get_contents_for_client (std::string resource, int bo
     // This type of resource is special.
     // It is not one resource, but made out of two resources.
     // It fetches data from two resources and combines that into one.
-    Webserver_Request request {};
-    return resource_logic_cloud_get_comparison (&request, resource, book, chapter, verse, false);
+    Webserver_Request webserver_request {};
+    return resource_logic_cloud_get_comparison (webserver_request, resource, book, chapter, verse, false);
   }
   
   if (is_translated) {
     // Handle a translated resource.
     // This passes the resource title only
-    Webserver_Request request;
-    return resource_logic_cloud_get_translation (&request, resource, book, chapter, verse, false);
+    Webserver_Request webserver_request;
+    return resource_logic_cloud_get_translation (webserver_request, resource, book, chapter, verse, false);
   }
   
   // Nothing found.
@@ -539,18 +536,18 @@ std::string resource_logic_client_fetch_cache_from_cloud (std::string resource,
   bool cache = !in_array(resource, client_logic_no_cache_resources_get ());
   
   // Ensure that the cache for this resource exists on the client.
-  if (cache && !Database_Cache::exists (resource, book)) {
-    Database_Cache::create (resource, book);
+  if (cache && !database::cache::sql::exists (resource, book)) {
+    database::cache::sql::create (resource, book);
   }
   
   // If content is to be cached and the content exists in the cache, return that content.
-  if (cache && Database_Cache::exists (resource, book, chapter, verse)) {
-    return Database_Cache::retrieve (resource, book, chapter, verse);
+  if (cache && database::cache::sql::exists (resource, book, chapter, verse)) {
+    return database::cache::sql::retrieve (resource, book, chapter, verse);
   }
   
   // Fetch this resource from Bibledit Cloud.
-  std::string address = Database_Config_General::getServerAddress ();
-  int port = Database_Config_General::getServerPort ();
+  std::string address = database::config::general::get_server_address ();
+  int port = database::config::general::get_server_port ();
   if (!client_logic_client_enabled ()) {
     // If the client has not been connected to a cloud instance,
     // fetch the resource from the Bibledit Cloud demo.
@@ -560,16 +557,16 @@ std::string resource_logic_client_fetch_cache_from_cloud (std::string resource,
   
   std::string url = client_logic_url (address, port, sync_resources_url ());
   url = filter_url_build_http_query (url, "r", filter_url_urlencode (resource));
-  url = filter_url_build_http_query (url, "b", filter::strings::convert_to_string (book));
-  url = filter_url_build_http_query (url, "c", filter::strings::convert_to_string (chapter));
-  url = filter_url_build_http_query (url, "v", filter::strings::convert_to_string (verse));
+  url = filter_url_build_http_query (url, "b", std::to_string (book));
+  url = filter_url_build_http_query (url, "c", std::to_string (chapter));
+  url = filter_url_build_http_query (url, "v", std::to_string (verse));
   std::string error {};
   std::string content = filter_url_http_get (url, error, false);
   
   // Cache the content under circumstances.
   if (cache) {
-    if (database_cache_can_cache (error, content)) {
-      Database_Cache::cache (resource, book, chapter, verse, content);
+    if (database::cache::can_cache (error, content)) {
+      database::cache::sql::cache (resource, book, chapter, verse, content);
     }
   }
   if (!error.empty ()) {
@@ -749,8 +746,8 @@ std::string resource_logic_web_or_cache_get (std::string url, std::string& error
 {
 #ifndef HAVE_CLIENT
   // On the Cloud, check if the URL is in the cache.
-  if (database_filebased_cache_exists (url)) {
-    return database_filebased_cache_get (url);
+  if (database::cache::file::exists (url)) {
+    return database::cache::file::get (url);
   }
 #endif
 
@@ -760,9 +757,9 @@ std::string resource_logic_web_or_cache_get (std::string url, std::string& error
 
 #ifdef HAVE_CLOUD
   // In the Cloud, cache the response based on certain criteria.
-  bool cache = database_cache_can_cache (error, html);
+  const bool cache = database::cache::can_cache (error, html);
   if (cache) {
-    database_filebased_cache_put (url, html);
+    database::cache::file::put (url, html);
   }
 #endif
 
@@ -772,16 +769,15 @@ std::string resource_logic_web_or_cache_get (std::string url, std::string& error
 
 
 // Returns the page type for the resource selector.
-std::string resource_logic_selector_page (void * webserver_request)
+std::string resource_logic_selector_page (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request {static_cast<Webserver_Request *>(webserver_request)};
-  std::string page {request->query["page"]};
+  std::string page {webserver_request.query["page"]};
   return page;
 }
 
 
 // Returns the page which called the resource selector.
-std::string resource_logic_selector_caller (void * webserver_request)
+std::string resource_logic_selector_caller (Webserver_Request& webserver_request)
 {
   std::string caller = resource_logic_selector_page (webserver_request);
   if (caller == "view") caller = "organize";
@@ -809,7 +805,7 @@ void resource_logic_create_cache ()
   resource_logic_create_cache_running = true;
   
   // Get the signatures of the resources to cache.
-  std::vector <std::string> signatures = Database_Config_General::getResourcesToCache ();
+  std::vector <std::string> signatures = database::config::general::get_resources_to_cache ();
   // If there's nothing to cache, bail out.
   if (signatures.empty ()) return;
 
@@ -817,7 +813,7 @@ void resource_logic_create_cache ()
   // Remove this signature and store the remainder back into the configuration.
   std::string signature = signatures [0];
   signatures.erase (signatures.begin ());
-  Database_Config_General::setResourcesToCache (signatures);
+  database::config::general::set_resources_to_cache (signatures);
   size_t pos = signature.find_last_of (" ");
   std::string resource = signature.substr (0, pos);
   int book = filter::strings::convert_to_int (signature.substr (pos++));
@@ -843,14 +839,14 @@ void resource_logic_create_cache ()
   }
   
   // Database layout is per book: Create a database for this book.
-  Database_Cache::remove (resource, book);
-  Database_Cache::create (resource, book);
+  database::cache::sql::remove (resource, book);
+  database::cache::sql::create (resource, book);
   
   Database_Versifications database_versifications;
   std::vector <int> chapters = database_versifications.getMaximumChapters (book);
   for (const auto& chapter : chapters) {
 
-    Database_Logs::log ("Caching " + resource + " " + bookname + " " + filter::strings::convert_to_string (chapter), Filter_Roles::consultant ());
+    Database_Logs::log ("Caching " + resource + " " + bookname + " " + std::to_string (chapter), Filter_Roles::consultant ());
 
     // The verse numbers in the chapter.
     std::vector <int> verses = database_versifications.getMaximumVerses (book, chapter);
@@ -898,12 +894,12 @@ void resource_logic_create_cache ()
       // after restart, would always continue from that same book, from Leviticus,
       // and never finish. Therefore something should be cached, even if it's an empty string.
       if (server_is_installing_module) html.clear ();
-      Database_Cache::cache (resource, book, chapter, verse, html);
+      database::cache::sql::cache (resource, book, chapter, verse, html);
     }
   }
 
   // Done.
-  Database_Cache::ready (resource, book, true);
+  database::cache::sql::ready (resource, book, true);
   Database_Logs::log ("Completed caching " + resource + " " + bookname, Filter_Roles::consultant ());
   resource_logic_create_cache_running = false;
   
@@ -948,10 +944,10 @@ std::string resource_logic_bible_gateway_module_list_refresh ()
   if (error.empty ()) {
     std::vector <std::string> resources {};
     html =  filter::strings::html_get_element (html, "select");
-    xml_document document;
+    pugi::xml_document document;
     document.load_string (html.c_str());
-    xml_node select_node = document.first_child ();
-    for (xml_node option_node : select_node.children()) {
+    pugi::xml_node select_node = document.first_child ();
+    for (pugi::xml_node option_node : select_node.children()) {
       std::string cls = option_node.attribute ("class").value ();
       if (cls == "lang") continue;
       if (cls == "spacer") continue;
@@ -959,7 +955,7 @@ std::string resource_logic_bible_gateway_module_list_refresh ()
       resources.push_back (name);
     }
     filter_url_file_put_contents (path, filter::strings::implode (resources, "\n"));
-    Database_Logs::log ("Modules: " + filter::strings::convert_to_string (resources.size ()));
+    Database_Logs::log ("Modules: " + std::to_string (resources.size ()));
   } else {
     Database_Logs::log (error);
   }
@@ -1129,14 +1125,14 @@ std::string resource_external_convert_book_studylight (int book)
 }
 
 
-struct bible_gateway_walker: xml_tree_walker
+struct bible_gateway_walker: pugi::xml_tree_walker
 {
   bool skip_next_text = false;
   bool parsing = true;
   std::string text {};
   std::vector <std::string> footnotes {};
 
-  virtual bool for_each (xml_node& node) override
+  virtual bool for_each (pugi::xml_node& node) override
   {
     // Details of the current node.
     std::string classname = node.attribute ("class").value ();
@@ -1195,7 +1191,7 @@ std::string resource_logic_bible_gateway_get (std::string resource, int book, in
       resource.erase (pos);
       // Assemble the URL to fetch the chapter.
       std::string bookname = resource_logic_bible_gateway_book (book);
-      std::string url = "https://www.biblegateway.com/passage/?search=" + bookname + "+" + filter::strings::convert_to_string (chapter) + ":" + filter::strings::convert_to_string(verse) + "&version=" + resource;
+      std::string url = "https://www.biblegateway.com/passage/?search=" + bookname + "+" + std::to_string (chapter) + ":" + std::to_string(verse) + "&version=" + resource;
       // Fetch the html.
       std::string error {};
       std::string html = resource_logic_web_or_cache_get (url, error);
@@ -1208,16 +1204,16 @@ std::string resource_logic_bible_gateway_get (std::string resource, int book, in
         // The parser will also give the location where this mismatch occurs first.
         // The location where the mismatch occurs indicates the end of the relevant verses content.
         {
-          xml_document document;
-          xml_parse_result parse_result = document.load_string (html.c_str(), parse_default | parse_fragment);
+          pugi::xml_document document;
+          pugi::xml_parse_result parse_result = document.load_string (html.c_str(), pugi::parse_default | pugi::parse_fragment);
           if (parse_result.offset > 10) {
             size_t pos2 = static_cast<size_t>(parse_result.offset - 2);
             html.erase (pos2);
           }
         }
         // Parse the html fragment into a DOM.
-        std::string verse_s = filter::strings::convert_to_string (verse);
-        xml_document document;
+        std::string verse_s = std::to_string (verse);
+        pugi::xml_document document;
         document.load_string (html.c_str());
         // There can be cross references in the html.
         // These result in e.g. "A" or "B" scattered through the final text.
@@ -1226,13 +1222,13 @@ std::string resource_logic_bible_gateway_get (std::string resource, int book, in
         // <sup class='crossreference' data-cr='#cen-NASB-30388A'  data-link='(&lt;a href=&quot;#cen-NASB-30388A&quot; title=&quot;See cross-reference A&quot;&gt;A&lt;/a&gt;)'>(<a href="#cen-NASB-30388A" title="See cross-reference A">A</a>)</sup>
         {
           std::string selector = "//sup[@class='crossreference']";
-          xpath_node_set nodeset = document.select_nodes(selector.c_str());
+          pugi::xpath_node_set nodeset = document.select_nodes(selector.c_str());
           for (auto xrefnode: nodeset) xrefnode.node().parent().remove_child(xrefnode.node());
         }
         // Start parsing for actual text.
-        xml_node passage_text_node = document.first_child ();
-        xml_node passage_wrap_node = passage_text_node.first_child ();
-        xml_node passage_content_node = passage_wrap_node.first_child ();
+        pugi::xml_node passage_text_node = document.first_child ();
+        pugi::xml_node passage_wrap_node = passage_text_node.first_child ();
+        pugi::xml_node passage_content_node = passage_wrap_node.first_child ();
         bible_gateway_walker walker {};
         passage_content_node.traverse (walker);
         result.append (walker.text);
@@ -1245,10 +1241,10 @@ std::string resource_logic_bible_gateway_get (std::string resource, int book, in
           // XPath selector.
           // <li id="fen-TLB-20531a"><a href="#en-TLB-20531" title="Go to Matthew 1:17">Matthew 1:17</a> <span class='footnote-text'><i>These are fourteen,</i> literally, “So all the generations from Abraham unto David are fourteen.”</span></li>
           std::string selector = "//li[@id='" + footnote_id + "']/span[@class='footnote-text']";
-          xpath_node xpath = document.select_node(selector.c_str());
+          pugi::xpath_node xpath = document.select_node(selector.c_str());
           if (xpath) {
             std::stringstream ss {};
-            xpath.node().print (ss, "", format_raw);
+            xpath.node().print (ss, "", pugi::format_raw);
             std::string selected_html = ss.str ();
             std::string footnote_text = filter::strings::html2text (selected_html);
             result.append ("<br>Note: ");
@@ -1321,7 +1317,7 @@ std::string resource_logic_study_light_module_list_refresh ()
     // Store the resources in a file.
     filter_url_file_put_contents (path, filter::strings::implode (resources, "\n"));
     // Done.
-    Database_Logs::log ("Modules: " + filter::strings::convert_to_string (resources.size ()));
+    Database_Logs::log ("Modules: " + std::to_string (resources.size ()));
   } else {
     Database_Logs::log (error);
   }
@@ -1363,7 +1359,7 @@ std::string resource_logic_study_light_get (std::string resource, int book, int
   url.append ("http://www.studylight.org/commentaries/");
   url.append (resource + "/");
   url.append (resource_external_convert_book_studylight (book));
-  url.append ("-" + filter::strings::convert_to_string (chapter) + ".html");
+  url.append ("-" + std::to_string (chapter) + ".html");
   
   // Get the html from the server.
   std::string error {};
@@ -1394,24 +1390,24 @@ std::string resource_logic_study_light_get (std::string resource, int book, int
 //  if (pos != std::string::npos) html.erase (0, pos);
 
   // Parse the html into a DOM.
-  std::string verse_s {filter::strings::convert_to_string (verse)};
-  xml_document document {};
+  std::string verse_s {std::to_string (verse)};
+  pugi::xml_document document {};
   pugi::xml_parse_result parse_result = document.load_string (html.c_str());
   pugixml_utils_error_logger (&parse_result, html);
 
   // Example verse indicator within the XML:
   // <a name="verses-2-10"></a>
   // <a name="verse-2"></a>
-  std::string selector1 = "//a[contains(@name,'verses-" + filter::strings::convert_to_string (verse) + "-')]";
-  std::string selector2 = "//a[@name='verse-" + filter::strings::convert_to_string (verse) + "']";
+  std::string selector1 = "//a[contains(@name,'verses-" + std::to_string (verse) + "-')]";
+  std::string selector2 = "//a[@name='verse-" + std::to_string (verse) + "']";
   std::string selector = selector1 + "|" + selector2;
-  xpath_node_set nodeset = document.select_nodes(selector.c_str());
+  pugi::xpath_node_set nodeset = document.select_nodes(selector.c_str());
   nodeset.sort();
-  for (xpath_node xpathnode : nodeset) {
-    xml_node h3_node = xpathnode.node().parent();
-    xml_node div_node = h3_node.parent();
+  for (pugi::xpath_node xpathnode : nodeset) {
+    pugi::xml_node h3_node = xpathnode.node().parent();
+    pugi::xml_node div_node = h3_node.parent();
     std::stringstream ss {};
-    div_node.print (ss, "", format_raw);
+    div_node.print (ss, "", pugi::format_raw);
     result.append(ss.str ());
   }
 #endif
@@ -1462,7 +1458,7 @@ std::vector <std::string> resource_logic_easy_english_bible_pages (int book, int
     case 18: return { "job-lbw" }; // Job.
     case 19: // Psalms.
     {
-      std::string number = filter::strings::fill (filter::strings::convert_to_string (chapter), 3, '0');
+      std::string number = filter::strings::fill (std::to_string (chapter), 3, '0');
       return { "psalm" + number + "-taw" };
     }
     case 20: return { "proverbs-lbw" }; // Proverbs.
@@ -1555,11 +1551,11 @@ std::vector <std::string> resource_logic_easy_english_bible_pages (int book, int
 }
 
 
-struct easy_english_bible_walker: xml_tree_walker
+struct easy_english_bible_walker: pugi::xml_tree_walker
 {
   std::string text {};
 
-  virtual bool for_each (xml_node& node) override
+  virtual bool for_each (pugi::xml_node& node) override
   {
     // Handle this node if it's a text node.
     if (node.type() == pugi::node_pcdata) {
@@ -1638,7 +1634,7 @@ std::string resource_logic_easy_english_bible_get (int book, int chapter, int ve
     if (pos != std::string::npos) html.erase (0, pos);
     
     // Parse the html into a DOM.
-    xml_document document {};
+    pugi::xml_document document {};
     document.load_string (html.c_str());
     
     // The document has one main div like this:
@@ -1646,8 +1642,8 @@ std::string resource_logic_easy_english_bible_get (int book, int chapter, int ve
     // Or: <div class="WordSection1"> like in Exodus.
     // That secion has many children all containing one paragraph of text.
     std::string selector = "//div[contains(@class, 'Section1')]";
-    xpath_node xnode = document.select_node(selector.c_str());
-    xml_node div_node = xnode.node();
+    pugi::xpath_node xnode = document.select_node(selector.c_str());
+    pugi::xml_node div_node = xnode.node();
 
     // Iterate over the paragraphs of text and process them.
     for (auto paragraph_node : div_node.children()) {
@@ -1704,7 +1700,7 @@ std::string resource_logic_easy_english_bible_get (int book, int chapter, int ve
         // But in Psalms this confuses things again.
         if (!at_passage) {
           if (book != 19) {
-            std::string tag = "v" + filter::strings::convert_to_string(verse);
+            std::string tag = "v" + std::to_string(verse);
             if (paragraph.find(tag) != std::string::npos) {
               at_passage = true;
               continue;
@@ -1750,7 +1746,7 @@ bool resource_logic_easy_english_bible_handle_chapter_heading (const std::string
   // The above is 19 characters long, so set the limit slightly higher.
   if (paragraph.length() <= 25) {
     if (paragraph.find ("Proverbs chapter") == 0) {
-      std::string tag = "Proverbs chapter " + filter::strings::convert_to_string(chapter);
+      std::string tag = "Proverbs chapter " + std::to_string(chapter);
       near_passage = (paragraph == tag);
       if (near_passage) {
         // If this paragraph contains a passage, it likely is a heading.
@@ -1762,7 +1758,7 @@ bool resource_logic_easy_english_bible_handle_chapter_heading (const std::string
       }
     }
     if (paragraph.find ("Chapter ") == 0) {
-      std::string tag = "Chapter " + filter::strings::convert_to_string(chapter);
+      std::string tag = "Chapter " + std::to_string(chapter);
       near_passage = (paragraph == tag);
       if (near_passage) {
         // If this paragraph contains a passage, it likely is a heading.
@@ -1808,14 +1804,14 @@ bool resource_logic_easy_english_bible_handle_passage_heading (const std::string
   if (hyphen_pos == std::string::npos) return false;
   std::string ch_fragment = last_word.substr(0, colon_pos);
   int starting_chapter = filter::strings::convert_to_int(ch_fragment);
-  std::string check = filter::strings::convert_to_string(starting_chapter);
+  std::string check = std::to_string(starting_chapter);
   if (ch_fragment != check) return false;
 
   // Look for the first hyphen.
   // This will provide the starting verse number.
   std::string vs_fragment = last_word.substr(colon_pos + 1, hyphen_pos - colon_pos - 1);
   int starting_verse = filter::strings::convert_to_int(vs_fragment);
-  check = filter::strings::convert_to_string(starting_verse);
+  check = std::to_string(starting_verse);
   if (vs_fragment != check) return false;
   last_word.erase (0, hyphen_pos + 1);
   
@@ -1830,14 +1826,14 @@ bool resource_logic_easy_english_bible_handle_passage_heading (const std::string
   if (colon_pos != std::string::npos) {
     std::string chapter_fragment = last_word.substr(0, colon_pos);
     ending_chapter = filter::strings::convert_to_int(chapter_fragment);
-    check = filter::strings::convert_to_string(ending_chapter);
+    check = std::to_string(ending_chapter);
     if (chapter_fragment != check) return false;
     last_word.erase(0, colon_pos + 1);
   }
 
   // The last bit of the fragment will now be the second verse number.
   int ending_verse = filter::strings::convert_to_int(last_word);
-  check = filter::strings::convert_to_string(ending_verse);
+  check = std::to_string(ending_verse);
   if (check != last_word) return false;
 
   // Set a flag if the passage that is to be obtained is within the current lines of text.
@@ -1873,13 +1869,13 @@ void resource_logic_easy_english_bible_handle_verse_marker (const std::string& p
   // The space at the end is to prevent it from matching more verses.
   // Like when looking for "Verse 1", it would be found in "Verse 10" too.
   // Hence the space.
-  std::string tag = "Verse " + filter::strings::convert_to_string(verse) + " ";
+  std::string tag = "Verse " + std::to_string(verse) + " ";
   at_passage = paragraph.find(tag) == 0;
   // If it's at the passage, then it's done parsing.
   if (at_passage) return;
 
   // If no verse is found yet, look for e.g. "Verse 13:".
-  tag = "Verse " + filter::strings::convert_to_string(verse) + ":";
+  tag = "Verse " + std::to_string(verse) + ":";
   at_passage = paragraph.find(tag) == 0;
   //If it's at the passage, then it's done parsing.
   if (at_passage) return;
@@ -1887,7 +1883,7 @@ void resource_logic_easy_english_bible_handle_verse_marker (const std::string& p
   // If no verse is found yet, look for the same tag but without the space at the end.
   // Then the entire paragraph should consist of this tag.
   // This occurs in Genesis 1 for example.
-  tag = "Verse " + filter::strings::convert_to_string(verse);
+  tag = "Verse " + std::to_string(verse);
   at_passage = (paragraph == tag);
   //If it's at the passage, then it's done parsing.
   if (at_passage) return;
@@ -1940,8 +1936,7 @@ void resource_logic_easy_english_bible_handle_verse_marker (const std::string& p
 
 bool resource_logic_is_bible (std::string resource)
 {
-  Database_Bibles database_bibles {};
-  std::vector <std::string> names = database_bibles.getBibles ();
+  std::vector <std::string> names = database::bibles::get_bibles ();
   return in_array (resource, names);
 }
 
