@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,28 +34,26 @@
 #include <menu/logic.h>
 
 
-string search_all_url ()
+std::string search_all_url ()
 {
   return "search/all";
 }
 
 
-bool search_all_acl (void * webserver_request)
+bool search_all_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) return true;
-  auto [ read, write ] =  AccessBible::Any (webserver_request);
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) 
+    return true;
+  auto [ read, write ] =  access_bible::any (webserver_request);
   return read;
 }
 
 
-string search_all (void * webserver_request)
+std::string search_all (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  
-  string page;
-  Assets_Header header = Assets_Header (translate("Search"), request);
-  header.addBreadCrumb (menu_logic_search_menu (), menu_logic_search_text ());
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Search"), webserver_request);
+  header.add_bread_crumb (menu_logic_search_menu (), menu_logic_search_text ());
   page = header.run ();
 
   
@@ -64,9 +62,9 @@ string search_all (void * webserver_request)
   
   // The query: The word or string to search for.
   // Put the query string into the search box.
-  string queryString;
-  if (request->query.count ("q")) {
-    queryString = request->query ["q"];
+  std::string queryString;
+  if (webserver_request.query.count ("q")) {
+    queryString = webserver_request.query ["q"];
   }
   
   
@@ -74,50 +72,50 @@ string search_all (void * webserver_request)
 
   
   // Clean the query string up.
-  queryString = filter_string_trim (queryString);
+  queryString = filter::strings::trim (queryString);
   
   
   // Generate search words for emphasizing the search passages.
-  vector <string> queryWords = filter_string_explode (queryString, ' ');
+  std::vector <std::string> queryWords = filter::strings::explode (queryString, ' ');
   
   
-  Database_Notes database_notes = Database_Notes (request);
+  Database_Notes database_notes (webserver_request);
 
   
-  string siteUrl = config_logic_site_url (webserver_request);
+  const std::string site_url = config::logic::site_url (webserver_request);
 
   
-  vector <string> bibles = AccessBible::Bibles (request);
+  std::vector <std::string> bibles = access_bible::bibles (webserver_request);
 
 
   // Search the notes.
-  vector <int> identifiers = database_notes.search_notes (queryString, bibles);
+  std::vector <int> identifiers = database_notes.search_notes (queryString, bibles);
   
   
-  size_t noteCount = identifiers.size();
-  view.set_variable ("noteCount", convert_to_string (noteCount));
+  size_t note_count = identifiers.size();
+  view.set_variable ("note_count", std::to_string (note_count));
   
   
   // Assemble the block of search results for the consultation notes.
-  string notesblock;
+  std::string notesblock;
   for (auto identifier : identifiers) {
     
     // The title.
-    string summary = database_notes.get_summary (identifier);
-    string verses = filter_passage_display_inline (database_notes.get_passages (identifier));
-    string title = summary + " | " + verses;
-    title = escape_special_xml_characters (title);
+    std::string summary = database_notes.get_summary (identifier);
+    std::string verses = filter_passage_display_inline (database_notes.get_passages (identifier));
+    std::string title = summary + " | " + verses;
+    title = filter::strings::escape_special_xml_characters (title);
     
     // The url.
-    string url = siteUrl + notes_note_url () + "?id=" + convert_to_string (identifier);
+    std::string url = site_url + notes_note_url () + "?id=" + std::to_string (identifier);
     
     // The excerpt.
-    string stext = database_notes.get_search_field (identifier);
-    vector <string> vtext = filter_string_explode (stext, '\n');
-    string excerpt;
+    std::string stext = database_notes.get_search_field (identifier);
+    std::vector <std::string> vtext = filter::strings::explode (stext, '\n');
+    std::string excerpt;
     // Go through each line of text separately.
     for (auto & line : vtext) {
-      string markedLine = filter_string_markup_words (queryWords, line);
+      std::string markedLine = filter::strings::markup_words (queryWords, line);
       // If the line is marked up, add it to the excerpts.
       if (!excerpt.empty()) excerpt.append ("\n");
       if (markedLine != line) {
@@ -126,7 +124,7 @@ string search_all (void * webserver_request)
     }
     
     // The html to display.
-    string html = "<p style=\"margin-top: 0.75em; margin-bottom: 0em\"><a href=\"";
+    std::string html = "<p style=\"margin-top: 0.75em; margin-bottom: 0em\"><a href=\"";
     html.append (url);
     html.append ("\">");
     html.append (title);
@@ -142,29 +140,29 @@ string search_all (void * webserver_request)
   
   
   // Search the Bible text.
-  vector <Passage> passages = search_logic_search_text (queryString, bibles);
+  std::vector <Passage> passages = search_logic_search_text (queryString, bibles);
   
   
   size_t textCount = passages.size ();
-  view.set_variable ("textCount", convert_to_string (textCount));
+  view.set_variable ("textCount", std::to_string (textCount));
   
   
   // Assemble the search results for the Bible text.
-  string textblock;
+  std::string textblock;
   for (auto & passage : passages) {
-    string bible = passage.m_bible;
+    std::string bible = passage.m_bible;
     int book = passage.m_book;
     int chapter = passage.m_chapter;
-    string verse = passage.m_verse;
+    std::string verse = passage.m_verse;
     // The title plus link.
-    string link = bible + " | " + filter_passage_link_for_opening_editor_at (book, chapter, verse);
+    std::string link = bible + " | " + filter_passage_link_for_opening_editor_at (book, chapter, verse);
     // The excerpt.
-    string stext = search_logic_get_bible_verse_text (bible, book, chapter, convert_to_int (verse));
-    vector <string> vtext = filter_string_explode (stext, '\n');
-    string excerpt;
+    std::string stext = search_logic_get_bible_verse_text (bible, book, chapter, filter::strings::convert_to_int (verse));
+    std::vector <std::string> vtext = filter::strings::explode (stext, '\n');
+    std::string excerpt;
     // Go through each line of text separately.
     for (auto & line : vtext) {
-      string markedLine = filter_string_markup_words (queryWords, line);
+      std::string markedLine = filter::strings::markup_words (queryWords, line);
       if (markedLine != line) {
         // Store this bit of the excerpt.
         excerpt.append ("<p style=\"margin-top: 0em\">" + markedLine + "</p>\n");
@@ -186,7 +184,7 @@ string search_all (void * webserver_request)
   page += view.render ("search", "all");
   
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   
   return page;
