@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_SEARCH_SEARCH_H
-#define INCLUDED_SEARCH_SEARCH_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string search_all_url ();
-bool search_all_acl (void * webserver_request);
-string search_all (void * webserver_request);
-
-
-#endif
+std::string search_all_url ();
+bool search_all_acl (Webserver_Request& webserver_request);
+std::string search_all (Webserver_Request& webserver_request);
