@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -32,45 +32,44 @@
 #include <ipc/focus.h>
 #include <menu/logic.h>
 #include <dialog/list2.h>
-using namespace std;
 
 
-string search_replace2_url ()
+std::string search_replace2_url ()
 {
   return "search/replace2";
 }
 
 
-bool search_replace2_acl (void * webserver_request)
+bool search_replace2_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
   auto [ read, write ] = access_bible::any (webserver_request);
   return write;
 }
 
 
-string search_replace2 (void * webserver_request)
+std::string search_replace2 (Webserver_Request& webserver_request)
 {
   // Build the advanced replace page.
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  string bible = request->database_config_user()->getBible ();
+  std::string bible = webserver_request.database_config_user()->getBible ();
   
   // Set the user chosen Bible as the current Bible.
-  if (request->post.count ("bibleselect")) {
-    string bibleselect = request->post ["bibleselect"];
-    request->database_config_user ()->setBible (bibleselect);
-    return string();
+  if (webserver_request.post.count ("bibleselect")) {
+    std::string bibleselect = webserver_request.post ["bibleselect"];
+    webserver_request.database_config_user ()->setBible (bibleselect);
+    return std::string();
   }
 
-  string page;
-  Assets_Header header = Assets_Header (translate("Replace"), request);
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Replace"), webserver_request);
   header.add_bread_crumb (menu_logic_search_menu (), menu_logic_search_text ());
   page = header.run ();
   Assets_View view;
 
   {
-    string bible_html;
-    vector <string> bibles = access_bible::bibles (request);
+    std::string bible_html;
+    std::vector <std::string> bibles = access_bible::bibles (webserver_request);
     for (auto selectable_bible : bibles) {
       bible_html = Options_To_Select::add_selection (selectable_bible, selectable_bible, bible_html);
     }
@@ -78,8 +77,8 @@ string search_replace2 (void * webserver_request)
   }
 
   view.set_variable ("bible", bible);
-  stringstream script {};
-  script << "var searchBible = " << quoted(bible) << ";";
+  std::stringstream script {};
+  script << "var searchBible = " << std::quoted(bible) << ";";
   view.set_variable ("script", script.str());
   page += view.render ("search", "replace2");
   page += assets_page::footer ();
