@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,46 +34,44 @@
 #include <access/bible.h>
 
 
-string search_strong_url ()
+std::string search_strong_url ()
 {
   return "search/strong";
 }
 
 
-bool search_strong_acl (void * webserver_request)
+bool search_strong_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ()))
+    return true;
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string search_strong (void * webserver_request)
+std::string search_strong (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-
   Database_Kjv database_kjv = Database_Kjv ();
   
   
-  string bible = request->database_config_user()->getBible ();
-  if (request->query.count ("b")) {
-    bible = request->query ["b"];
+  std::string bible = webserver_request.database_config_user()->getBible ();
+  if (webserver_request.query.count ("b")) {
+    bible = webserver_request.query ["b"];
   }
   
   
-  if (request->query.count ("load")) {
+  if (webserver_request.query.count ("load")) {
 
-    int book = Ipc_Focus::getBook (request);
-    int chapter = Ipc_Focus::getChapter (request);
-    int verse = Ipc_Focus::getVerse (request);
+    const int book = Ipc_Focus::getBook (webserver_request);
+    const int chapter = Ipc_Focus::getChapter (webserver_request);
+    const int verse = Ipc_Focus::getVerse (webserver_request);
     
     // Get Strong's numbers, plus English snippets.
-    string html = "<table>\n";
-    vector <Database_Kjv_Item> details = database_kjv.getVerse (book, chapter, verse);
+    std::string html = "<table>\n";
+    std::vector <Database_Kjv_Item> details = database_kjv.getVerse (book, chapter, verse);
     for (auto & detail : details) {
-      string strong = detail.strong;
-      string english = detail.english;
+      std::string strong = detail.strong;
+      std::string english = detail.english;
       html += "<tr><td><a href=\"" + strong + "\">" + strong + "</a></td><td>" + english + "</td></tr>\n";
     }
     html += "</table>\n";
@@ -82,70 +80,71 @@ string search_strong (void * webserver_request)
   }
   
   
-  if (request->query.count ("strong")) {
+  if (webserver_request.query.count ("strong")) {
     
-    string strong = request->query ["strong"];
-    strong = filter_string_trim (strong);
+    std::string strong = webserver_request.query ["strong"];
+    strong = filter::strings::trim (strong);
     
-    vector <int> passages;
+    std::vector <int> passages;
     
-    vector <Passage> details = database_kjv.searchStrong (strong);
+    std::vector <Passage> details = database_kjv.searchStrong (strong);
     
     for (auto & passage : details) {
       int i_passage = filter_passage_to_integer (passage);
       passages.push_back (i_passage);
     }
     
-    passages = array_unique (passages);
+    passages = filter::strings::array_unique (passages);
     sort (passages.begin(), passages.end());
     
-    string output;
+    std::string output;
     for (auto & passage : passages) {
       if (!output.empty()) output.append ("\n");
-      output.append (convert_to_string (passage));
+      output.append (std::to_string (passage));
     }
     return output;
   }
   
   
-  if (request->query.count ("id")) {
-    int id = convert_to_int (request->query ["id"]);
+  if (webserver_request.query.count ("id")) {
+    int id = filter::strings::convert_to_int (webserver_request.query ["id"]);
     
     // Get the and passage for this identifier.
     Passage passage = filter_integer_to_passage (id);
     int book = passage.m_book;
     int chapter = passage.m_chapter;
-    string verse = passage.m_verse;
+    std::string verse = passage.m_verse;
     
     // Get the plain text.
-    string text = search_logic_get_bible_verse_text (bible, book, chapter, convert_to_int (verse));
+    std::string text = search_logic_get_bible_verse_text (bible, book, chapter, filter::strings::convert_to_int (verse));
     
     // Format it.
-    string link = filter_passage_link_for_opening_editor_at (book, chapter, verse);
-    string output = "<div>" + link + " " + text + "</div>";
+    std::string link = filter_passage_link_for_opening_editor_at (book, chapter, verse);
+    std::string output = "<div>" + link + " " + text + "</div>";
     
     // Output to browser.
     return output;
   }
   
   
-  string page;
+  std::string page;
   
-  Assets_Header header = Assets_Header (translate("Search"), request);
-  header.setNavigator ();
-  header.addBreadCrumb (menu_logic_search_menu (), menu_logic_search_text ());
+  Assets_Header header = Assets_Header (translate("Search"), webserver_request);
+  header.set_navigator ();
+  header.add_bread_crumb (menu_logic_search_menu (), menu_logic_search_text ());
   page = header.run ();
   
   Assets_View view;
   
   view.set_variable ("bible", bible);
   
-  string script = "var searchBible = \"" + bible + "\";";
-  view.set_variable ("script", script);
+  std::stringstream script {};
+  script << "var searchBible = " << std::quoted(bible) << ";";
+  view.set_variable ("script", script.str());
 
   page += view.render ("search", "strong");
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   return page;
 }
