@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,17 +17,11 @@
  */
 
 
-#ifndef INCLUDED_SENDRECEIVE_CHANGES_H
-#define INCLUDED_SENDRECEIVE_CHANGES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string sendreceive_changes_sendreceive_text ();
-string sendreceive_changes_up_to_date_text ();
+std::string sendreceive_changes_sendreceive_text ();
+std::string sendreceive_changes_up_to_date_text ();
 void sendreceive_changes ();
 void sendreceive_changes_kick_watchdog ();
-
-
-#endif
