@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,14 @@
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Weffc++"
 #pragma GCC diagnostic ignored "-Wold-style-cast"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
 #ifdef HAVE_ICU
 #include <unicode/ustdio.h>
 #include <unicode/normlzr.h>
@@ -35,20 +42,14 @@
 #pragma GCC diagnostic pop
 
 
-using namespace pugi;
-#ifdef HAVE_ICU
-using namespace icu;
-#endif
+int entry_element_count {0};
 
 
-int entry_element_count = 0;
-
-
-void sources_abbott_smith_parse_entry_element (Database_AbbottSmith * database_abbottsmith,
-                                               xml_node & node)
+void sources_abbott_smith_parse_entry_element (pugi::xml_node & node)
 {
-  string entry = "entry";
-  if (node.name() != entry) return;
+  std::string entry = "entry";
+  if (node.name() != entry) 
+    return;
   entry_element_count++;
   
   // Example <entry> element and its content:
@@ -63,14 +64,14 @@ void sources_abbott_smith_parse_entry_element (Database_AbbottSmith * database_a
   //</entry>
 
   // Get the lemma, and the Strong's number, and the raw XML of the entry's contents.
-  string lemma = filter_string_trim (node.attribute ("lemma").value ());
+  std::string lemma = filter::strings::trim (node.attribute ("lemma").value ());
 #ifdef HAVE_ICU
-  lemma = icu_string_normalize (lemma, true, true);
+  lemma = filter::strings::icu_string_normalize (lemma, true, true);
 #endif
-  string strong = filter_string_trim (node.attribute ("strong").value ());
-  stringstream ss;
-  for (xml_node child : node.children()) child.print(ss, "", format_raw);
-  string contents = ss.str ();
+  std::string strong = filter::strings::trim (node.attribute ("strong").value ());
+  std::stringstream ss;
+  for (pugi::xml_node child : node.children()) child.print(ss, "", pugi::format_raw);
+  std::string contents = ss.str ();
   
   // If there's no lemma, or no Strong's number, then there's nothing to store.
   if (lemma.empty () && strong.empty()) return;
@@ -80,7 +81,7 @@ void sources_abbott_smith_parse_entry_element (Database_AbbottSmith * database_a
   // It means that a Strong's number is added to the lemma.
   // Such a Strong's number should be parsed too, and put at its proper place in the database.
   // And the lemma should be remove from its attached Strong's number.
-  vector <string> strongs = filter_string_explode (lemma, '|');
+  std::vector <std::string> strongs = filter::strings::explode (lemma, '|');
   if (strongs.size() >= 2) {
     lemma = strongs[0];
     strongs.erase (strongs.begin());
@@ -90,47 +91,46 @@ void sources_abbott_smith_parse_entry_element (Database_AbbottSmith * database_a
 
   // Store the original lemma, the casefolded lemma, and the Strong's number,
   // together with the entry's raw XML, into the database.
-  string lemma_case_folded = unicode_string_casefold (lemma);
-  database_abbottsmith->store (lemma, lemma_case_folded, strong, contents);
+  std::string lemma_case_folded = filter::strings::unicode_string_casefold (lemma);
+  database::abboth_smith::store (lemma, lemma_case_folded, strong, contents);
   
   // If there's more Strong's numbers in the entry, store those too, but without any lemma.
   for (auto strong2 : strongs) {
-    database_abbottsmith->store (string(), string(), strong2, contents);
+    database::abboth_smith::store (std::string(), std::string(), strong2, contents);
   }
 }
 
 
 void sources_abbott_smith_parse ()
 {
-  cout << "Starting" << endl;
-  Database_AbbottSmith database_abbottsmith;
-  database_abbottsmith.create ();
+  std::cout << "Starting" << std::endl;
+  database::abboth_smith::create ();
     
-  string file = "sources/abbott-smith/abbott-smith.tei_lemma.xml";
+  std::string file = "sources/abbott-smith/abbott-smith.tei_lemma.xml";
   
-  xml_document document;
+  pugi::xml_document document;
   document.load_file (file.c_str());
-  xml_node TEI_node = document.first_child ();
+  pugi::xml_node TEI_node = document.first_child ();
   // Do a deep parsing.
   // The depth as used below was found out empirically in March 2021.
   // The number of <entry> elements was 6153 when counted in a text editor.
   // And this same number of elements was found when parsing as deep as is done below.
-  for (xml_node node1 : TEI_node.children()) {
-    sources_abbott_smith_parse_entry_element (&database_abbottsmith, node1);
-    for (xml_node node2 : node1.children()) {
-      sources_abbott_smith_parse_entry_element (&database_abbottsmith, node2);
-      for (xml_node node3 : node2.children()) {
-        sources_abbott_smith_parse_entry_element (&database_abbottsmith, node3);
-        for (xml_node node4 : node3.children()) {
-          sources_abbott_smith_parse_entry_element (&database_abbottsmith, node4);
-          for (xml_node node5 : node4.children()) {
-            sources_abbott_smith_parse_entry_element (&database_abbottsmith, node5);
+  for (pugi::xml_node node1 : TEI_node.children()) {
+    sources_abbott_smith_parse_entry_element (node1);
+    for (pugi::xml_node node2 : node1.children()) {
+      sources_abbott_smith_parse_entry_element (node2);
+      for (pugi::xml_node node3 : node2.children()) {
+        sources_abbott_smith_parse_entry_element (node3);
+        for (pugi::xml_node node4 : node3.children()) {
+          sources_abbott_smith_parse_entry_element (node4);
+          for (pugi::xml_node node5 : node4.children()) {
+            sources_abbott_smith_parse_entry_element (node5);
           }
         }
       }
     }
   }
-  cout << entry_element_count << " entry elements parsed" << endl;
-  database_abbottsmith.optimize ();
-  cout << "Completed" << endl;
+  std::cout << entry_element_count << " entry elements parsed" << std::endl;
+  database::abboth_smith::optimize ();
+  std::cout << "Completed" << std::endl;
 }
