@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -25,30 +25,34 @@
 #include <filter/url.h>
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
 #pragma GCC diagnostic pop
 
 
-using namespace pugi;
-
-
 // Declarations local functions.
-void sources_kjv_store (int book, int chapter, int verse, string lemma, string english);
-void sources_kjv_parse_loop (xml_node element, int & book, int & chapter, int & verse, bool & within_verse, string & lemma);
+void sources_kjv_store (int book, int chapter, int verse, std::string lemma, std::string english);
+void sources_kjv_parse_loop (pugi::xml_node element, int & book, int & chapter, int & verse, bool & within_verse, std::string & lemma);
 
 
-void sources_kjv_store (int book, int chapter, int verse, string lemma, string english)
+void sources_kjv_store (int book, int chapter, int verse, std::string lemma, std::string english)
 {
   Database_Kjv database_kjv;
-  vector <string> lemmas = filter_string_explode (lemma, ' ');
+  std::vector <std::string> lemmas = filter::strings::explode (lemma, ' ');
   bool output_done = false;
   for (auto & strong : lemmas) {
-    if (strong.find ("strong") == string::npos) continue;
+    if (strong.find ("strong") == std::string::npos) continue;
     if (output_done) {
       // Two separate two identical words.
       database_kjv.store (book, chapter, verse, "", " / ");
     }
-    strong = filter_string_str_replace ("strong:", "", strong);
+    strong = filter::strings::replace ("strong:", "", strong);
     database_kjv.store (book, chapter, verse, strong, english);
     output_done = true;
   }
@@ -58,77 +62,77 @@ void sources_kjv_store (int book, int chapter, int verse, string lemma, string e
 }
 
 
-void sources_kjv_parse_loop (xml_node element,
+void sources_kjv_parse_loop (pugi::xml_node element,
                              int & book, int & chapter, int & verse,
-                             bool & within_verse, string & lemma)
+                             bool & within_verse, std::string & lemma)
 {
-  string element_name = element.name ();
+  std::string element_name = element.name ();
   if (element_name == "verse") {
-    string sID = element.attribute ("sID").value ();
+    std::string sID = element.attribute ("sID").value ();
     if (!sID.empty ()) {
       verse++;
       within_verse = true;
     }
-    string eID = element.attribute ("eID").value ();
+    std::string eID = element.attribute ("eID").value ();
     if (!eID.empty ()) {
       within_verse = false;
     }
   } else if (element_name == "w") {
     if (within_verse) {
       lemma = element.attribute ("lemma").value ();
-      lemma = filter_string_trim (lemma);
-      for (xml_node child : element.children ()) {
+      lemma = filter::strings::trim (lemma);
+      for (pugi::xml_node child : element.children ()) {
         sources_kjv_parse_loop (child, book, chapter, verse, within_verse, lemma);
       }
     }
   } else if (element_name.empty ()) {
     if (within_verse) {
-      string english = element.value ();
+      std::string english = element.value ();
       sources_kjv_store (book, chapter, verse, lemma, english);
     }
   } else if (element_name == "note") {
-    xml_node textnode = element.first_child ();
-    string english = textnode.text ().get ();
+    pugi::xml_node textnode = element.first_child ();
+    std::string english = textnode.text ().get ();
     english.insert (0, " [");
     english.append ("]");
     sources_kjv_store (book, chapter, verse, "", english);
   } else if (element_name == "milestone") {
   } else if (element_name == "transChange") {
-    xml_node textnode = element.first_child ();
-    string english = textnode.text ().get ();
+    pugi::xml_node textnode = element.first_child ();
+    std::string english = textnode.text ().get ();
     english.insert (0, "<span style=\"font-style:italic;\">");
     english.append ("</span>");
     sources_kjv_store (book, chapter, verse, "", english);
   } else if (element_name == "inscription") {
-    for (xml_node child : element.children ()) {
-      string tmp_lemma;
+    for (pugi::xml_node child : element.children ()) {
+      std::string tmp_lemma;
       sources_kjv_parse_loop (child, book, chapter, verse, within_verse, tmp_lemma);
     }
   } else if (element_name == "q") {
-    for (xml_node child : element.children ()) {
-      string tmp_lemma;
+    for (pugi::xml_node child : element.children ()) {
+      std::string tmp_lemma;
       sources_kjv_parse_loop (child, book, chapter, verse, within_verse, tmp_lemma);
     }
   } else if (element_name == "divineName") {
-    for (xml_node child : element.children ()) {
-      string tmp_lemma;
+    for (pugi::xml_node child : element.children ()) {
+      std::string tmp_lemma;
       sources_kjv_parse_loop (child, book, chapter, verse, within_verse, tmp_lemma);
     }
   } else if (element_name == "title") {
-    for (xml_node child : element.children ()) {
-      string tmp_lemma;
+    for (pugi::xml_node child : element.children ()) {
+      std::string tmp_lemma;
       sources_kjv_parse_loop (child, book, chapter, verse, within_verse, tmp_lemma);
     }
   } else if (element_name == "foreign") {
-    for (xml_node child : element.children ()) {
-      string tmp_lemma;
+    for (pugi::xml_node child : element.children ()) {
+      std::string tmp_lemma;
       sources_kjv_parse_loop (child, book, chapter, verse, within_verse, tmp_lemma);
     }
   } else {
     if (within_verse) {
-      xml_node textnode = element.first_child ();
-      string english = textnode.text ().get ();
-      string location = filter_passage_display (book, chapter, convert_to_string (verse));
+      pugi::xml_node textnode = element.first_child ();
+      std::string english = textnode.text ().get ();
+      std::string location = filter_passage_display (book, chapter, std::to_string (verse));
       Database_Logs::log (location + ": Failed to parse element " + element_name + " with value " + english);
     }
   }
@@ -147,22 +151,22 @@ void sources_kjv_parse ()
   int verse = 0;
   bool within_verse = false;
 
-  xml_document document;
-  document.load_file ("sources/kjv.xml", parse_ws_pcdata);
-  for (xml_node osis : document.children ()) {
-    for (xml_node osisText : osis.children ()) {
-      for (xml_node divbook : osisText.children ()) {
+  pugi::xml_document document;
+  document.load_file ("sources/kjv.xml", pugi::parse_ws_pcdata);
+  for (pugi::xml_node osis : document.children ()) {
+    for (pugi::xml_node osisText : osis.children ()) {
+      for (pugi::xml_node divbook : osisText.children ()) {
         if (strcmp (divbook.name (), "div") == 0) {
           book++;
-          Database_Logs::log ("Book " + convert_to_string (book));
+          Database_Logs::log ("Book " + std::to_string (book));
           chapter = 0;
-          for (xml_node chapter_element : divbook.children ()) {
+          for (pugi::xml_node chapter_element : divbook.children ()) {
             if (strcmp (chapter_element.name (), "chapter") == 0) {
               chapter++;
               verse = 0;
               within_verse = false;
-              for (xml_node element : chapter_element.children ()) {
-                string lemma;
+              for (pugi::xml_node element : chapter_element.children ()) {
+                std::string lemma;
                 sources_kjv_parse_loop (element, book, chapter, verse, within_verse, lemma);
               }
             }
