@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 // The name of the "Standard" stylesheet.
-string styles_logic_standard_sheet ()
+std::string styles_logic_standard_sheet ()
 {
   return "Standard";
 }
@@ -31,7 +31,7 @@ string styles_logic_standard_sheet ()
 
 // This contains the styles logic.
 // categoryText - Returns the $category as human readable text.
-string styles_logic_category_text (string category)
+std::string styles_logic_category_text (std::string category)
 {
   if (category == "id")  return translate ("Identification information");
   if (category == "ith") return translate ("Introduction titles and headings");
@@ -56,7 +56,7 @@ string styles_logic_category_text (string category)
 
 
 // Returns the $type as human readable text.
-string styles_logic_type_text (int type)
+std::string styles_logic_type_text (int type)
 {
   if (type == StyleTypeIdentifier     ) return translate ("is an identifier");
   if (type == StyleTypeStartsParagraph) return translate ("starts a new paragraph");
@@ -74,8 +74,8 @@ string styles_logic_type_text (int type)
 }
 
 
-// subtypeText - Returns the $subtype as human readable text.
-string styles_logic_subtype_text (int type, int subtype)
+// This returns the $subtype as human readable text.
+std::string styles_logic_subtype_text (int type, int subtype)
 {
   if (type == StyleTypeIdentifier) {
     if (subtype == IdentifierSubtypeBook                  ) return translate ("identifies the book");
@@ -148,7 +148,7 @@ string styles_logic_subtype_text (int type, int subtype)
 }
 
 
-// Returns true if the fontsize is relevant for $type and $subtype
+// Returns true if the fontsize is relevant for $type and $subtype.
 bool styles_logic_fontsize_is_relevant (int type, int subtype)
 {
   switch (type) {
@@ -158,7 +158,8 @@ bool styles_logic_fontsize_is_relevant (int type, int subtype)
     {
       switch (subtype) {
         case FootEndNoteSubtypeStandardContent : return true;
-        case FootEndNoteSubtypeParagraph       : return true;
+        case FootEndNoteSubtypeParagraph : return true;
+        default: return false;
       }
       break;
     }
@@ -166,17 +167,24 @@ bool styles_logic_fontsize_is_relevant (int type, int subtype)
     {
       switch (subtype) {
         case CrossreferenceSubtypeStandardContent : return true;
+        default: return false;
       }
       break;
     }
+    case StyleTypePicture :
+    {
+      return true;
+    }
     case StyleTypeTableElement :
     {
       switch (subtype) {
         case TableElementSubtypeHeading : return true;
         case TableElementSubtypeCell    : return true;
+        default: return false;
       }
       break;
     }
+    default: return false;
   }
   return false;
 }
@@ -192,14 +200,17 @@ bool styles_logic_italic_bold_underline_smallcaps_are_relevant (int type, int su
     case StyleTypeVerseNumber     : return true;
     case StyleTypeFootEndNote     : return true;
     case StyleTypeCrossreference  : return true;
+    case StyleTypePicture         : return true;
     case StyleTypeTableElement :
     {
       switch (subtype) {
         case TableElementSubtypeHeading : return true;
         case TableElementSubtypeCell    : return true;
+        default: return false;
       }
       break;
     }
+    default: return false;
   }
   return false;
 }
@@ -209,34 +220,37 @@ bool styles_logic_italic_bold_underline_smallcaps_are_relevant (int type, int su
 bool styles_logic_italic_bold_underline_smallcaps_are_full (int type, int subtype)
 {
   switch (type) {
-    case StyleTypeInlineText  : return true;
-    case StyleTypeVerseNumber : return true;
-    case StyleTypeFootEndNote :
+    case StyleTypeInlineText: return true;
+    case StyleTypeVerseNumber: return true;
+    case StyleTypeFootEndNote:
     {
       switch (subtype) {
-        case FootEndNoteSubtypeFootnote             : return true;
-        case FootEndNoteSubtypeEndnote              : return true;
-        case FootEndNoteSubtypeContent              : return true;
-        case FootEndNoteSubtypeContentWithEndmarker : return true;
+        case FootEndNoteSubtypeFootnote: return true;
+        case FootEndNoteSubtypeEndnote: return true;
+        case FootEndNoteSubtypeContent: return true;
+        case FootEndNoteSubtypeContentWithEndmarker: return true;
+        default: return false;
       }
       break;
     }
-    case StyleTypeCrossreference :
+    case StyleTypeCrossreference:
     {
       switch (subtype) {
-        case CrossreferenceSubtypeCrossreference       : return true;
-        case CrossreferenceSubtypeContent              : return true;
-        case CrossreferenceSubtypeContentWithEndmarker : return true;
+        case CrossreferenceSubtypeCrossreference: return true;
+        case CrossreferenceSubtypeContent: return true;
+        case CrossreferenceSubtypeContentWithEndmarker: return true;
+        default: return false;
       }
       break;
     }
+    default: return false;
   }
   return false;
 }
 
 
 // Returns the $value as human readable text.
-string styles_logic_off_on_inherit_toggle_text (int value)
+std::string styles_logic_off_on_inherit_toggle_text (int value)
 {
   if (value == ooitOff    ) return translate ("Off");
   if (value == ooitOn     ) return translate ("On");
@@ -259,6 +273,7 @@ bool styles_logic_superscript_is_relevant (int type, int subtype)
         case FootEndNoteSubtypeEndnote         : return true;
         case FootEndNoteSubtypeStandardContent : return true;
         case FootEndNoteSubtypeParagraph       : return true;
+        default: return false;
       }
       break;
     }
@@ -267,9 +282,11 @@ bool styles_logic_superscript_is_relevant (int type, int subtype)
       switch (subtype) {
         case CrossreferenceSubtypeCrossreference        : return true;
         case CrossreferenceSubtypeStandardContent       : return true;
+        default: return false;
       }
       break;
     }
+    default: return false;
   }
   return false;
 }
@@ -286,6 +303,7 @@ bool styles_logic_paragraph_treats_are_relevant (int type, int subtype)
       switch (subtype) {
         case FootEndNoteSubtypeStandardContent : return true;
         case FootEndNoteSubtypeParagraph       : return true;
+        default: return false;
       }
       break;
     }
@@ -293,24 +311,28 @@ bool styles_logic_paragraph_treats_are_relevant (int type, int subtype)
     {
       switch (subtype) {
         case CrossreferenceSubtypeStandardContent : return true;
+        default: return false;
       }
       break;
     }
+    case StyleTypePicture : return true;
     case StyleTypeTableElement :
     {
       switch (subtype) {
         case TableElementSubtypeHeading : return true;
         case TableElementSubtypeCell    : return true;
+        default: return false;
       }
       break;
     }
+    default: return false;
   }
   return false;
 }
 
 
 // Returns the $value as human readable text.
-string styles_logic_alignment_text (int value)
+std::string styles_logic_alignment_text (int value)
 {
   if (value == AlignmentLeft   ) return translate ("Left align");
   if (value == AlignmentCenter ) return translate ("Center");
@@ -327,6 +349,7 @@ bool styles_logic_columns_are_relevant (int type, int subtype)
   switch (type) {
     case StyleTypeStartsParagraph : return true;
     case StyleTypeChapterNumber   : return true;
+    default: return false;
   }
   return false;
 }
@@ -343,6 +366,7 @@ bool styles_logic_color_is_relevant (int type, int subtype)
       switch (subtype) {
         case FootEndNoteSubtypeContent              : return true;
         case FootEndNoteSubtypeContentWithEndmarker : return true;
+        default: return false;
       }
       break;
     }
@@ -351,9 +375,11 @@ bool styles_logic_color_is_relevant (int type, int subtype)
       switch (subtype) {
         case CrossreferenceSubtypeContent              : return true;
         case CrossreferenceSubtypeContentWithEndmarker : return true;
+        default: return false;
       }
       break;
     }
+    default: return false;
   }
   return false;
 }
@@ -369,6 +395,7 @@ bool styles_logic_print_is_relevant (int type, int subtype)
       switch (subtype) {
         case FootEndNoteSubtypeFootnote : return true;
         case FootEndNoteSubtypeEndnote  : return true;
+        default: return false;
       }
       break;
     }
@@ -376,9 +403,11 @@ bool styles_logic_print_is_relevant (int type, int subtype)
     {
       switch (subtype) {
         case CrossreferenceSubtypeCrossreference  : return true;
+        default: return false;
       }
       break;
     }
+    default: return false;
   }
   return false;
 }
@@ -410,15 +439,16 @@ int styles_logic_get_userbool1_function (int type, int subtype)
 
 
 // Returns the text of userbool1's function.
-string styles_logic_get_userbool1_text (int function)
+std::string styles_logic_get_userbool1_text (int function)
 {
   switch (function) {
-    case UserBool1PrintChapterAtFirstVerse : return translate ("Print chapter number at first verse");
-    case UserBool1IdStartsNewPage          : return translate ("Start on a new page");
-    case UserBool1NoteAppliesToApocrypha   : return translate ("Refers to the Apocrypha");
-    case UserBool1VerseRestartsParagraph   : return translate ("Restart paragraph");
+    case UserBool1PrintChapterAtFirstVerse: return translate ("Print chapter number at first verse");
+    case UserBool1IdStartsNewPage: return translate ("Start on a new page");
+    case UserBool1NoteAppliesToApocrypha: return translate ("Refers to the Apocrypha");
+    case UserBool1VerseRestartsParagraph: return translate ("Restart paragraph");
+    default: return "--";
   }
-  return "--";
+  return std::string();
 }
 
 
@@ -437,14 +467,15 @@ int styles_logic_get_userbool2_function (int type, int subtype)
 
 
 // Returns the text of userbool2's function.
-string styles_logic_get_userbool2_text (int function)
+std::string styles_logic_get_userbool2_text (int function)
 {
   switch (function) {
-    case UserBool2IdStartsOddPage            : return translate ("New page starts with an odd number (not implemented due to limitations in OpenDocument)");
-    case UserBool2ChapterInLeftRunningHeader : return translate ("Print chapter number in the running header of the left page");
-    case UserBool2RunningHeaderLeft          : return translate ("Print this in the running header of the left page");
+    case UserBool2IdStartsOddPage: return translate ("New page starts with an odd number (not implemented due to limitations in OpenDocument)");
+    case UserBool2ChapterInLeftRunningHeader: return translate ("Print chapter number in the running header of the left page");
+    case UserBool2RunningHeaderLeft: return translate ("Print this in the running header of the left page");
+    default: return std::string();
   }
-  return "";
+  return std::string();
 }
 
 
@@ -463,13 +494,14 @@ int styles_logic_get_userbool3_function (int type, int subtype)
 
 
 // Returns the text of userbool3's function.
-string styles_logic_get_userbool3_text (int function)
+std::string styles_logic_get_userbool3_text (int function)
 {
   switch (function) {
-    case UserBool3ChapterInRightRunningHeader : return translate ("Print chapter number in the running header of the right page");
-    case UserBool3RunningHeaderRight          : return translate ("Print this in the running header of the right page");
+    case UserBool3ChapterInRightRunningHeader: return translate ("Print chapter number in the running header of the right page");
+    case UserBool3RunningHeaderRight: return translate ("Print this in the running header of the right page");
+    default: return std::string();
   }
-  return "";
+  return std::string();
 }
 
 
@@ -497,12 +529,12 @@ int styles_logic_get_userint1_function (int type, int subtype)
 
 
 // Returns the value as human readable text for note numbering.
-string styles_logic_note_numbering_text (int value)
+std::string styles_logic_note_numbering_text (int value)
 {
   if (value == NoteNumbering123 ) return "1, 2, 3 ...";
   if (value == NoteNumberingAbc ) return "a, b, c ...";
   if (value == NoteNumberingUser) return translate ("User defined sequence");
-  return convert_to_string (value);
+  return std::to_string (value);
 }
 
 
@@ -524,22 +556,22 @@ int styles_logic_get_userint2_function (int type, int subtype)
 
 
 // Returns the value as human readable text for when to restart the note numbering.
-string styles_logic_note_restart_numbering_text (int value)
+std::string styles_logic_note_restart_numbering_text (int value)
 {
   if (value == NoteRestartNumberingNever       ) return translate ("Never");
   if (value == NoteRestartNumberingEveryBook   ) return translate ("Every book");
   if (value == NoteRestartNumberingEveryChapter) return translate ("Every chapter");
-  return convert_to_string (value);
+  return std::to_string (value);
 }
 
 
 // Returns the value as human readable text for the position of the endnotes.
-string styles_logic_end_note_position_text (int value)
+std::string styles_logic_end_note_position_text (int value)
 {
   if (value == EndNotePositionAfterBook) return translate ("After each book");
   if (value == EndNotePositionVeryEnd  ) return translate ("After everything else");
   if (value == EndNotePositionAtMarker ) return translate ("Upon encountering a certain marker");
-  return convert_to_string (value);
+  return std::to_string (value);
 }
 
 
@@ -599,79 +631,64 @@ bool styles_logic_starts_new_line_in_usfm (int type, int subtype)
   switch (type) {
     case StyleTypeIdentifier :
     {
-      if (subtype == IdentifierSubtypePublishedVerseMarker) {
-        return false;
-      } else {
-        return true;
-      }
-      break;
+      if (subtype == IdentifierSubtypePublishedVerseMarker) return false;
+      return true;
     }
     case StyleTypeNotUsedComment :
     {
       return true;
-      break;
     }
     case StyleTypeNotUsedRunningHeader :
     {
       return true;
-      break;
     }
     case StyleTypeStartsParagraph :
     {
       return true;
-      break;
     }
     case StyleTypeInlineText :
     {
       return false;
-      break;
     }
     case StyleTypeChapterNumber :
     {
       return true;
-      break;
     }
     case StyleTypeVerseNumber :
     {
       return true;
-      break;
     }
     case StyleTypeFootEndNote :
     {
       return false;
-      break;
     }
     case StyleTypeCrossreference :
     {
       return false;
-      break;
     }
     case StyleTypePeripheral :
     {
       return true;
-      break;
     }
     case StyleTypePicture :
     {
       return true;
-      break;
     }
     case StyleTypePageBreak :
     {
       return true;
-      break;
     }
     case StyleTypeTableElement :
     {
       if (subtype == TableElementSubtypeRow) return true;
       return false;
-      break;
     }
     case StyleTypeWordlistElement :
     {
       return false;
-      break;
     }
+    default:
+      return false;
   }
   return true;
 }
