@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,5 +21,7 @@
 
 #include <config/libraries.h>
 
-string sync_setup_url ();
-string sync_setup (void * webserver_request);
+class Webserver_Request;
+
+std::string sync_setup_url ();
+std::string sync_setup (Webserver_Request& webserver_request);
