@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,28 +29,25 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <locale/translate.h>
 #include <menu/logic.h>
 #include <database/logs.h>
-using namespace std;
 
 
-string system_googletranslate_url ()
+std::string system_googletranslate_url ()
 {
   return "system/googletranslate";
 }
 
 
-bool system_googletranslate_acl ([[maybe_unused]] void * webserver_request)
+bool system_googletranslate_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
 }
 
 
-string system_googletranslate (void * webserver_request)
+std::string system_googletranslate (Webserver_Request& webserver_request)
 {
-//  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  string page {};
-  string success {};
-  string error {};
+  std::string page {};
+  std::string success {};
+  std::string error {};
   
   // The header.
   Assets_Header header = Assets_Header (translate("Google Translate"), webserver_request);
@@ -92,8 +89,8 @@ string system_googletranslate (void * webserver_request)
   }
 
   // Do a translation.
-  string english_text { "Jesus the Christ the Messiah" };
-  string greek_text;
+  std::string english_text { "Jesus the Christ the Messiah" };
+  std::string greek_text;
   if (error.empty()) {
     auto [ trans_ok, translation, trans_err ] = filter::google::translate (english_text, "en", "el");
     if (!trans_ok) error.assign(trans_err);
@@ -102,16 +99,16 @@ string system_googletranslate (void * webserver_request)
   
   // Handle the OK message.
   if (error.empty()) if (json_key.length()) {
-    stringstream ss;
+    std::stringstream ss;
     ss << translate("The connection to Google Translate looks good.");
     ss << " ";
     ss << translate("An example translation was made.");
     ss << " - ";
     ss << translate ("English") << ": ";
-    ss << quoted(english_text);
+    ss << std::quoted(english_text);
     ss << " - ";
     ss << translate ("Greek") << ": ";
-    ss << quoted(greek_text);
+    ss << std::quoted(greek_text);
     success = ss.str();
   }
   
