@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -35,13 +35,16 @@ Webserver_Request::Webserver_Request ()
 
 Webserver_Request::~Webserver_Request ()
 {
-  if (session_logic_instance) delete session_logic_instance;
-  if (database_config_user_instance) delete database_config_user_instance;
-  if (database_users_instance) delete database_users_instance;
-  if (database_styles_instance) delete database_styles_instance;
-  if (database_bibles_instance) delete database_bibles_instance;
-  if (database_check_instance) delete database_check_instance;
-  if (database_ipc_instance) delete database_ipc_instance;
+  if (session_logic_instance) 
+    delete session_logic_instance;
+  if (database_config_user_instance) 
+    delete database_config_user_instance;
+  if (database_users_instance) 
+    delete database_users_instance;
+  if (database_styles_instance) 
+    delete database_styles_instance;
+  if (database_ipc_instance)
+    delete database_ipc_instance;
 }
 
 
@@ -49,7 +52,8 @@ Webserver_Request::~Webserver_Request ()
 Session_Logic * Webserver_Request::session_logic ()
 {
   // Single live object during the entire web request.
-  if (!session_logic_instance) session_logic_instance = new Session_Logic (this);
+  if (!session_logic_instance) 
+    session_logic_instance = new Session_Logic (*this);
   return session_logic_instance;
 }
 
@@ -58,7 +62,8 @@ Session_Logic * Webserver_Request::session_logic ()
 Database_Config_User * Webserver_Request::database_config_user ()
 {
   // Single live object during the entire web request.
-  if (!database_config_user_instance) database_config_user_instance = new Database_Config_User (this);
+  if (!database_config_user_instance) 
+    database_config_user_instance = new Database_Config_User (*this);
   return database_config_user_instance;
 }
 
@@ -67,35 +72,24 @@ Database_Config_User * Webserver_Request::database_config_user ()
 Database_Users * Webserver_Request::database_users ()
 {
   // Single live object during the entire web request.
-  if (!database_users_instance) database_users_instance = new Database_Users ();
+  if (!database_users_instance) 
+    database_users_instance = new Database_Users ();
   return database_users_instance;
 }
 
 
 Database_Styles * Webserver_Request::database_styles ()
 {
-  if (!database_styles_instance) database_styles_instance = new Database_Styles ();
+  if (!database_styles_instance) 
+    database_styles_instance = new Database_Styles ();
   return database_styles_instance;
 }
 
 
-Database_Bibles * Webserver_Request::database_bibles ()
-{
-  if (!database_bibles_instance) database_bibles_instance = new Database_Bibles ();
-  return database_bibles_instance;
-}
-
-
-Database_Check * Webserver_Request::database_check ()
-{
-  if (!database_check_instance) database_check_instance = new Database_Check ();
-  return database_check_instance;
-}
-
-
 Database_Ipc * Webserver_Request::database_ipc ()
 {
-  if (!database_ipc_instance) database_ipc_instance = new Database_Ipc (this);
+  if (!database_ipc_instance) 
+    database_ipc_instance = new Database_Ipc (*this);
   return database_ipc_instance;
 }
 
